@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -117,6 +117,7 @@ class APIBatchView(APIBatchMixin, APIMasterView):
             'executed_display': self.pretty_datetime(executed) if executed else None,
             'executed_by_uuid': batch.executed_by_uuid,
             'executed_by_display': six.text_type(batch.executed_by or ''),
+            'mutable': self.handler.is_mutable(batch),
         }
 
     def create_object(self, data):
@@ -268,6 +269,7 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
             'batch_description': batch.description,
             'batch_complete': batch.complete,
             'batch_executed': bool(batch.executed),
+            'batch_mutable': self.handler.is_mutable(batch),
             'sequence': row.sequence,
             'status_code': row.status_code,
             'status_display': row.STATUS.get(row.status_code, six.text_type(row.status_code)),
@@ -280,6 +282,9 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
         Invokes the batch handler's ``refresh_row()`` method after updating the
         row's field data per usual.
         """
+        if not self.handler.is_mutable(row.batch):
+            return {'error': "Batch is not mutable"}
+
         # update row per usual
         row = super(APIBatchRowView, self).update_object(row, data)
 
