@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -267,6 +267,9 @@ class OrderingBatchRowViews(APIBatchRowView):
 
         Note that the "normal" logic for this method is not invoked at all.
         """
+        if not self.handler.is_mutable(row.batch):
+            return {'error': "Batch is not mutable"}
+
         self.handler.update_row_quantity(row, **data)
         return row
 
