@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -345,8 +345,12 @@ class APIMasterView(APIView):
         # assume our data comes only from request JSON body
         data = self.request.json_body
 
-        # update and return data for object
+        # try to update data for object, returning error as necessary
         obj = self.update_object(obj, data)
+        if isinstance(obj, dict) and 'error' in obj:
+            return {'error': obj['error']}
+
+        # return data for object
         self.Session.flush()
         return self._get(obj)
 
