@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -339,7 +339,7 @@ class Form(object):
     auto_disable_save = True
     auto_disable_cancel = True
 
-    def __init__(self, fields=None, schema=None, request=None, mobile=False, readonly=False, readonly_fields=[],
+    def __init__(self, fields=None, schema=None, request=None, readonly=False, readonly_fields=[],
                  model_instance=None, model_class=None, appstruct=UNSPECIFIED, nodes={}, enums={}, labels={},
                  assume_local_times=False, renderers=None,
                  hidden={}, widgets={}, defaults={}, validators={}, required={}, helptext={}, focus_spec=None,
@@ -352,7 +352,6 @@ class Form(object):
         if self.fields is None and self.schema:
             self.set_fields([f.name for f in self.schema])
         self.request = request
-        self.mobile = mobile
         self.readonly = readonly
         self.readonly_fields = set(readonly_fields or [])
         self.model_instance = model_instance
@@ -786,7 +785,10 @@ class Form(object):
         the overall response, to be interpreted on the client side.
         """
         if isinstance(field.schema.typ, deform.FileData):
-            # TODO: don't recall why "always null" here?
+            # TODO: we used to always/only return 'null' here but hopefully
+            # this also works, to show existing filename when present
+            if field.cstruct and field.cstruct['filename']:
+                return json.dumps({'name': field.cstruct['filename']})
             return 'null'
 
         if isinstance(field.schema.typ, colander.Set):
