@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -130,23 +130,44 @@ class GridFilter(object):
         'is_any':               "is any",
         'equal':                "equal to",
         'not_equal':            "not equal to",
+        'equal_any_of':         "equal to any of",
         'greater_than':         "greater than",
         'greater_equal':        "greater than or equal to",
         'less_than':            "less than",
         'less_equal':           "less than or equal to",
+        'is_empty':             "is empty",
+        'is_not_empty':         "is not empty",
         'is_null':              "is null",
         'is_not_null':          "is not null",
         'is_true':              "is true",
         'is_false':             "is false",
         'is_false_null':        "is false or null",
+        'is_empty_or_null':     "is either empty or null",
         'contains':             "contains",
         'does_not_contain':     "does not contain",
+        'contains_any_of':      "contains any of",
         'is_me':                "is me",
         'is_not_me':            "is not me",
     }
 
-    valueless_verbs = ['is_any', 'is_null', 'is_not_null', 'is_true', 'is_false',
-                       'is_false_null', 'is_me', 'is_not_me']
+    valueless_verbs = [
+        'is_any',
+        'is_empty',
+        'is_not_empty',
+        'is_null',
+        'is_not_null',
+        'is_true',
+        'is_false',
+        'is_false_null',
+        'is_empty_or_null',
+        'is_me',
+        'is_not_me',
+    ]
+
+    multiple_value_verbs = [
+        'equal_any_of',
+        'contains_any_of',
+    ]
 
     value_renderer_factory = DefaultValueRenderer
     data_type = 'string'        # default, but will be set from value renderer
@@ -280,18 +301,6 @@ class GridFilter(object):
         return self.value_renderer.render(value=value, **kwargs)
 
 
-class MobileFilter(GridFilter):
-    """
-    Base class for mobile grid filters.
-    """
-    default_verbs = ['equal']
-
-    def __init__(self, key, **kwargs):
-        kwargs.setdefault('default_active', True)
-        kwargs.setdefault('default_verb', 'equal')
-        super(MobileFilter, self).__init__(key, **kwargs)
-
-
 class AlchemyGridFilter(GridFilter):
     """
     Base class for SQLAlchemy grid filters.
@@ -380,7 +389,12 @@ class AlchemyStringFilter(AlchemyGridFilter):
         Expose contains / does-not-contain verbs in addition to core.
         """
         return ['contains', 'does_not_contain',
-                'equal', 'not_equal', 'is_null', 'is_not_null', 'is_any']
+                'contains_any_of',
+                'equal', 'not_equal',
+                'is_empty', 'is_not_empty',
+                'is_null', 'is_not_null',
+                'is_empty_or_null',
+                'is_any']
 
     def filter_contains(self, query, value):
         """
@@ -408,6 +422,50 @@ class AlchemyStringFilter(AlchemyGridFilter):
                   for v in value.split()]),
         ))
 
+    def filter_contains_any_of(self, query, value):
+        """
+        This filter expects "multiple values" separated by newline character,
+        and will add an "OR" condition with each value being checked via
+        "ILIKE".  For instance if the user submits a "value" like this:
+
+        .. code-block:: none
+
+           foo bar
+           baz
+
+        This will result in SQL condition like this:
+
+        .. code-block:: sql
+
+           (name ILIKE '%foo%' AND name ILIKE '%bar%') OR name ILIKE '%baz%'
+        """
+        if not value:
+            return query
+
+        values = value.split('\n')
+        values = [value for value in values if value]
+        if not values:
+            return query
+
+        conditions = []
+        for value in values:
+            conditions.append(sa.and_(
+                *[self.column.ilike(self.encode_value('%{}%'.format(v)))
+                  for v in value.split()]))
+
+        return query.filter(sa.or_(*conditions))
+
+    def filter_is_empty(self, query, value):
+        return query.filter(sa.func.trim(self.column) == self.encode_value(''))
+
+    def filter_is_not_empty(self, query, value):
+        return query.filter(sa.func.trim(self.column) != self.encode_value(''))
+
+    def filter_is_empty_or_null(self, query, value):
+        return query.filter(
+            sa.or_(
+                sa.func.trim(self.column) == self.encode_value(''),
+                self.column == None))
 
 class AlchemyEmptyStringFilter(AlchemyStringFilter):
     """
@@ -533,6 +591,11 @@ class AlchemyIntegerFilter(AlchemyNumericFilter):
                 return True
         return False
 
+    def encode_value(self, value):
+        # ensure we pass integer value to sqlalchemy, so it does not try to
+        # encode it as a string etc.
+        return int(value)
+
 
 class AlchemyBooleanFilter(AlchemyGridFilter):
     """
@@ -863,7 +926,7 @@ class AlchemyGPCFilter(AlchemyGridFilter):
     """
     GPC filter for SQLAlchemy.
     """
-    default_verbs = ['equal', 'not_equal']
+    default_verbs = ['equal', 'not_equal', 'equal_any_of']
 
     def filter_equal(self, query, value):
         """
@@ -905,6 +968,47 @@ class AlchemyGPCFilter(AlchemyGridFilter):
         except ValueError:
             return query
 
+    def filter_equal_any_of(self, query, value):
+        """
+        This filter expects "multiple values" separated by newline character,
+        and will add an "OR" condition with each value being checked via
+        "ILIKE".  For instance if the user submits a "value" like this:
+
+        .. code-block:: none
+
+           07430500132
+           07430500116
+
+        This will result in SQL condition like this:
+
+        .. code-block:: sql
+
+           (upc IN (7430500132, 74305001321)) OR (upc IN (7430500116, 74305001161))
+        """
+        if not value:
+            return query
+
+        values = value.split('\n')
+        values = [value for value in values if value]
+        if not values:
+            return query
+
+        conditions = []
+        for value in values:
+            try:
+                clause = self.column.in_((
+                    GPC(value),
+                    GPC(value, calc_check_digit='upc')))
+            except ValueError:
+                pass
+            else:
+                conditions.append(clause)
+
+        if not conditions:
+            return query
+
+        return query.filter(sa.or_(*conditions))
+
 
 class AlchemyPhoneNumberFilter(AlchemyStringFilter):
     """
