@@ -8,6 +8,8 @@ const TailboneAutocomplete = {
         serviceUrl: String,
         value: String,
         initialLabel: String,
+        assignedValue: String,
+        assignedLabel: String,
     },
 
     data() {
@@ -43,7 +45,7 @@ const TailboneAutocomplete = {
             this.value = null
             if (focus) {
                 this.$nextTick(function() {
-                    this.$refs.autocomplete.focus()
+                    this.focus()
                 })
             }
 
@@ -51,6 +53,10 @@ const TailboneAutocomplete = {
             // $('#' + oid + '-textbox').trigger('autocompletevaluecleared');
         },
 
+        focus() {
+            this.$refs.autocomplete.focus()
+        },
+
         getDisplayText() {
             if (this.selected) {
                 return this.selected.label
