@@ -4,8 +4,14 @@ const NumericInput = {
         '<b-input',
         ':name="name"',
         ':value="value"',
-        '@focus="focus"',
-        '@blur="blur"',
+        'ref="input"',
+        ':placeholder="placeholder"',
+        ':size="size"',
+        ':icon-pack="iconPack"',
+        ':icon="icon"',
+        ':disabled="disabled"',
+        '@focus="notifyFocus"',
+        '@blur="notifyBlur"',
         '@keydown.native="keyDown"',
         '@input="valueChanged"',
         '>',
@@ -15,16 +21,25 @@ const NumericInput = {
     props: {
         name: String,
         value: String,
+        placeholder: String,
+        iconPack: String,
+        icon: String,
+        size: String,
+        disabled: Boolean,
         allowEnter: Boolean
     },
 
     methods: {
 
-        focus(event) {
+        focus() {
+            this.$refs.input.focus()
+        },
+
+        notifyFocus(event) {
             this.$emit('focus', event)
         },
 
-        blur(event) {
+        notifyBlur(event) {
             this.$emit('blur', event)
         },
 
