@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -42,7 +42,9 @@ from webhelpers2.html import tags
 import tailbone
 from tailbone import helpers
 from tailbone.db import Session
+from tailbone.config import csrf_header_name
 from tailbone.menus import make_simple_menus
+from tailbone.util import should_use_buefy
 
 
 def new_request(event):
@@ -106,6 +108,7 @@ def before_render(event):
     renderer_globals['datetime'] = datetime
     renderer_globals['colander'] = colander
     renderer_globals['deform'] = deform
+    renderer_globals['csrf_header_name'] = csrf_header_name(request.rattail_config)
 
     # theme  - we only want do this for classic web app, *not* API
     # TODO: so, clearly we need a better way to distinguish the two
@@ -143,6 +146,16 @@ def before_render(event):
             renderer_globals['background_color'] = request.rattail_config.get(
                 'tailbone', 'background_color')
 
+        # maybe set custom stylesheet for Buefy themes
+        if should_use_buefy(request):
+            css = None
+            if request.user:
+                css = request.rattail_config.get('tailbone.{}'.format(request.user.uuid),
+                                                 'buefy_css')
+            if not css:
+                css = request.rattail_config.get('tailbone', 'theme.falafel.buefy_css')
+            renderer_globals['buefy_css'] = css
+
         # here we globally declare widths for grid filter pseudo-columns
         widths = request.rattail_config.get('tailbone', 'grids.filters.column_widths')
         if widths:
@@ -206,7 +219,7 @@ def context_found(event):
         return False
     request.has_any_perm = has_any_perm
 
-    def get_referrer(default=None, mobile=False):
+    def get_referrer(default=None, **kwargs):
         if request.params.get('referrer'):
             return request.params['referrer']
         if request.session.get('referrer'):
@@ -216,8 +229,6 @@ def context_found(event):
             or not referrer.startswith(request.host_url)):
             if default:
                 referrer = default
-            elif mobile:
-                referrer = request.route_url('mobile.home')
             else:
                 referrer = request.route_url('home')
         return referrer
