@@ -1,23 +1,23 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2016 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
 #  Rattail is free software: you can redistribute it and/or modify it under the
-#  terms of the GNU Affero General Public License as published by the Free
-#  Software Foundation, either version 3 of the License, or (at your option)
-#  any later version.
+#  terms of the GNU General Public License as published by the Free Software
+#  Foundation, either version 3 of the License, or (at your option) any later
+#  version.
 #
 #  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
-#  more details.
+#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+#  details.
 #
-#  You should have received a copy of the GNU Affero General Public License
-#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU General Public License along with
+#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
 """
@@ -27,37 +27,19 @@ Pyramid Views
 from __future__ import unicode_literals, absolute_import
 
 from .core import View
-from tailbone.views.grids import (
-    GridView, AlchemyGridView, SortableAlchemyGridView,
-    PagedAlchemyGridView, SearchableAlchemyGridView)
-from .crud import CrudView
 from .master import MasterView
-from tailbone.views.autocomplete import AutocompleteView
 
-
-def home(request):
-    """
-    Default home view.
-    """
-
-    return {}
-
-
-def add_routes(config):
-    config.add_route('home', '/')
+# TODO: deprecate / remove some of this
+from .autocomplete import AutocompleteView
 
 
 def includeme(config):
-    add_routes(config)
 
-    config.add_view(home, route_name='home',
-                    renderer='/home.mako')
-
-    config.include('tailbone.views.core')
+    # core views
     config.include('tailbone.views.common')
-
     config.include('tailbone.views.auth')
-    config.include('tailbone.views.batches')
+
+    # main table views
     config.include('tailbone.views.bouncer')
     config.include('tailbone.views.brands')
     config.include('tailbone.views.categories')
@@ -85,5 +67,11 @@ def includeme(config):
     config.include('tailbone.views.stores')
     config.include('tailbone.views.subdepartments')
     config.include('tailbone.views.taxes')
+    config.include('tailbone.views.upgrades')
     config.include('tailbone.views.users')
     config.include('tailbone.views.vendors')
+
+    # batch views
+    config.include('tailbone.views.batch.newproduct')
+    config.include('tailbone.views.batch.pricing')
+    config.include('tailbone.views.batch.product')
