@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -87,12 +87,11 @@ class AuthenticationView(View):
         self.request.session.flash(msg, allow_duplicate=False)
         return self.redirect(next_url)
 
-    def login(self, mobile=False):
+    def login(self, **kwargs):
         """
         The login view, responsible for displaying and handling the login form.
         """
-        home = 'mobile.home' if mobile else 'home'
-        referrer = self.request.get_referrer(default=self.request.route_url(home))
+        referrer = self.request.get_referrer(default=self.request.route_url('home'))
 
         # redirect if already logged in
         if self.request.user:
@@ -124,21 +123,21 @@ class AuthenticationView(View):
             'tailbone', 'main_image_url',
             default=self.request.static_url('tailbone:static/img/home_logo.png'))
 
-        return {
+        context = {
             'form': form,
             'referrer': referrer,
             'image_url': image_url,
             'use_buefy': use_buefy,
             'help_url': global_help_url(self.rattail_config),
         }
+        if use_buefy:
+            context['index_title'] = self.rattail_config.node_title()
+        return context
 
     def authenticate_user(self, username, password):
         return authenticate_user(Session(), username, password)
 
-    def mobile_login(self):
-        return self.login(mobile=True)
-
-    def logout(self, mobile=False):
+    def logout(self, **kwargs):
         """
         View responsible for logging out the current user.
 
@@ -150,17 +149,12 @@ class AuthenticationView(View):
 
         # redirect to home page after login, if so configured
         if self.rattail_config.getbool('tailbone', 'home_after_logout', default=False):
-            home = 'mobile.home' if mobile else 'home'
-            return self.redirect(self.request.route_url(home), headers=headers)
+            return self.redirect(self.request.route_url('home'), headers=headers)
 
         # otherwise redirect to referrer, with 'login' page as fallback
-        login = 'mobile.login' if mobile else 'login'
-        referrer = self.request.get_referrer(default=self.request.route_url(login))
+        referrer = self.request.get_referrer(default=self.request.route_url('login'))
         return self.redirect(referrer, headers=headers)
 
-    def mobile_logout(self):
-        return self.logout(mobile=True)
-
     def noop(self):
         """
         View to serve as "no-op" / ping action to reset current user's session timer
@@ -174,7 +168,7 @@ class AuthenticationView(View):
         if not self.request.user:
             return self.redirect(self.request.route_url('home'))
 
-        if self.user_is_protected(self.request.user):
+        if self.user_is_protected(self.request.user) and not self.request.is_root:
             self.request.session.flash("Cannot change password for user: {}".format(self.request.user))
             return self.redirect(self.request.get_referrer())
 
@@ -213,7 +207,6 @@ class AuthenticationView(View):
     @classmethod
     def defaults(cls, config):
         rattail_config = config.registry.settings.get('rattail_config')
-        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # forbidden
         config.add_forbidden_view(cls, attr='forbidden')
@@ -221,16 +214,10 @@ class AuthenticationView(View):
         # login
         config.add_route('login', '/login')
         config.add_view(cls, attr='login', route_name='login', renderer='/login.mako')
-        if legacy_mobile:
-            config.add_route('mobile.login', '/mobile/login')
-            config.add_view(cls, attr='mobile_login', route_name='mobile.login', renderer='/mobile/login.mako')
 
         # logout
         config.add_route('logout', '/logout')
         config.add_view(cls, attr='logout', route_name='logout')
-        if legacy_mobile:
-            config.add_route('mobile.logout', '/mobile/logout')
-            config.add_view(cls, attr='mobile_logout', route_name='mobile.logout')
 
         # no-op
         config.add_route('noop', '/noop')
