@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -38,6 +38,7 @@ from six import StringIO
 
 import json
 import six
+import markdown
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -83,9 +84,6 @@ class BatchMasterView(MasterView):
     executable = True
     results_refreshable = False
     results_executable = False
-    supports_mobile = True
-    mobile_filterable = True
-    mobile_rows_viewable = True
     has_worksheet = False
     has_worksheet_file = False
 
@@ -175,15 +173,13 @@ class BatchMasterView(MasterView):
 
         kwargs['execute_title'] = self.get_execute_title(batch)
         kwargs['execute_enabled'] = self.instance_executable(batch)
-        if kwargs['mobile']:
-            if self.mobile_rows_creatable:
-                kwargs.setdefault('add_item_title', "Add Item")
-            if self.mobile_rows_quickable:
-                kwargs.setdefault('quick_entry_placeholder', "Enter {}".format(
-                    self.rattail_config.product_key_title()))
         if kwargs['execute_enabled']:
             url = self.get_action_url('execute', batch)
             kwargs['execute_form'] = self.make_execute_form(batch, action_url=url)
+            description = (self.handler.describe_execution(batch)
+                           or "TODO: handler does not provide a description for this batch")
+            kwargs['execution_described'] = markdown.markdown(
+                description, extensions=['fenced_code', 'codehilite'])
         else:
             kwargs['why_not_execute'] = self.handler.why_not_execute(batch)
 
@@ -337,18 +333,6 @@ class BatchMasterView(MasterView):
             return "{} {}".format(batch.id_str, batch.description)
         return batch.id_str
 
-    def get_mobile_data(self, session=None):
-        return super(BatchMasterView, self).get_mobile_data(session=session)\
-                                           .order_by(self.model_class.id.desc())
-
-    def make_mobile_filters(self):
-        """
-        Returns a set of filters for the mobile grid.
-        """
-        filters = grids.filters.GridFilterSet()
-        filters['status'] = MobileBatchStatusFilter(self.model_class, 'status', default_value='pending')
-        return filters
-
     def configure_form(self, f):
         super(BatchMasterView, self).configure_form(f)
 
@@ -433,10 +417,10 @@ class BatchMasterView(MasterView):
             return text
 
         if batch.complete:
-            label = "Mark as NOT Complete"
+            label = "Mark Incomplete"
             value = 'false'
         else:
-            label = "Mark as Complete"
+            label = "Mark Complete"
             value = 'true'
 
         kwargs = {}
@@ -488,28 +472,6 @@ class BatchMasterView(MasterView):
         url = self.request.route_url('users.view', uuid=user.uuid)
         return tags.link_to(title, url)
 
-    def configure_mobile_form(self, f):
-        super(BatchMasterView, self).configure_mobile_form(f)
-        batch = f.model_instance
-
-        if self.creating:
-            f.remove_fields('id',
-                            'rowcount',
-                            'created',
-                            'created_by',
-                            'cognized',
-                            'cognized_by',
-                            'executed',
-                            'executed_by',
-                            'purge')
-
-        else: # not creating
-            if not batch.executed:
-                f.remove_fields('executed',
-                                'executed_by')
-                if not batch.complete:
-                    f.remove_field('complete')
-
     def save_create_form(self, form):
         uploads = self.normalize_uploads(form)
         self.before_create(form)
@@ -547,28 +509,7 @@ class BatchMasterView(MasterView):
             os.remove(upload['temp_path'])
             os.rmdir(upload['tempdir'])
 
-    def save_mobile_create_form(self, form):
-        self.before_create(form)
-        session = self.Session()
-        with session.no_autoflush:
-
-            # transfer form data to batch instance
-            batch = self.objectify(form, self.form_deserialized)
-
-            # current user is batch creator
-            batch.created_by = self.request.user
-
-            # TODO: is this still necessary with colander?
-            # destroy initial batch and re-make using handler
-            kwargs = self.get_batch_kwargs(batch)
-            if batch in session:
-                session.expunge(batch)
-            batch = self.handler.make_batch(session, **kwargs)
-
-        session.flush()
-        return batch
-
-    def get_batch_kwargs(self, batch, mobile=False):
+    def get_batch_kwargs(self, batch, **kwargs):
         """
         Return a kwargs dict for use with ``self.handler.make_batch()``, using
         the given batch as a template.
@@ -599,13 +540,13 @@ class BatchMasterView(MasterView):
         """
         return True
 
-    def redirect_after_create(self, batch, mobile=False):
+    def redirect_after_create(self, batch, **kwargs):
         if self.handler.should_populate(batch):
-            return self.redirect(self.get_action_url('prefill', batch, mobile=mobile))
+            return self.redirect(self.get_action_url('prefill', batch))
         elif self.refresh_after_create:
-            return self.redirect(self.get_action_url('refresh', batch, mobile=mobile))
+            return self.redirect(self.get_action_url('refresh', batch))
         else:
-            return self.redirect(self.get_action_url('view', batch, mobile=mobile))
+            return self.redirect(self.get_action_url('view', batch))
 
     def template_kwargs_edit(self, **kwargs):
         batch = kwargs['instance']
@@ -631,16 +572,6 @@ class BatchMasterView(MasterView):
     def mark_batch_incomplete(self, batch):
         self.handler.mark_incomplete(batch)
 
-    def mobile_mark_complete(self):
-        batch = self.get_instance()
-        self.mark_batch_complete(batch)
-        return self.redirect(self.get_index_url(mobile=True))
-
-    def mobile_mark_pending(self):
-        batch = self.get_instance()
-        self.mark_batch_incomplete(batch)
-        return self.redirect(self.get_action_url('view', batch, mobile=True))
-
     def rows_creatable_for(self, batch):
         """
         Only allow creating new rows on a batch if it hasn't yet been executed
@@ -703,16 +634,6 @@ class BatchMasterView(MasterView):
             return self.redirect(self.get_action_url('view', batch))
         return super(BatchMasterView, self).create_row()
 
-    def mobile_create_row(self):
-        """
-        Only allow creating a new row if the batch hasn't yet been executed.
-        """
-        batch = self.get_instance()
-        if batch.executed:
-            self.request.session.flash("You cannot add new rows to a batch which has been executed")
-            return self.redirect(self.get_action_url('view', batch, mobile=True))
-        return super(BatchMasterView, self).mobile_create_row()
-
     def save_create_row_form(self, form):
         batch = self.get_instance()
         row = self.objectify(form, self.form_deserialized)
@@ -739,19 +660,6 @@ class BatchMasterView(MasterView):
         # status text
         f.set_readonly('status_text')
 
-    def configure_mobile_row_form(self, f):
-        super(BatchMasterView, self).configure_mobile_row_form(f)
-
-        # sequence
-        f.set_readonly('sequence')
-
-        # status_code
-        if self.model_row_class:
-            f.set_enum('status_code', self.model_row_class.STATUS)
-        f.set_renderer('status_code', self.render_row_status)
-        f.set_readonly('status_code')
-        f.set_label('status_code', "Status")
-
     def make_default_row_grid_tools(self, batch):
         if self.rows_creatable and not batch.executed and not batch.complete:
             permission_prefix = self.get_permission_prefix()
@@ -803,9 +711,6 @@ class BatchMasterView(MasterView):
     def make_row_grid_tools(self, batch):
         return (self.make_default_row_grid_tools(batch) or '') + (self.make_batch_row_grid_tools(batch) or '')
 
-    def sort_mobile_row_data(self, query):
-        return query.order_by(self.model_row_class.sequence)
-
     def redirect_after_edit(self, batch):
         """
         If refresh flag is set, do that; otherwise go (back) to view/edit page.
@@ -821,12 +726,7 @@ class BatchMasterView(MasterView):
         self.handler.do_delete(batch)
         super(BatchMasterView, self).delete_instance(batch)
 
-    def get_fallback_templates(self, template, mobile=False):
-        if mobile:
-            return [
-                '/mobile/batch/{}.mako'.format(template),
-                '/mobile/master/{}.mako'.format(template),
-            ]
+    def get_fallback_templates(self, template, **kwargs):
         return [
             '/batch/{}.mako'.format(template),
             '/master/{}.mako'.format(template),
@@ -1088,13 +988,14 @@ class BatchMasterView(MasterView):
         except Exception as error:
             log.warning("%s of '%s' batch failed: %s", handler_action, self.handler.batch_key, batch_uuid, exc_info=True)
 
-            # TODO: write error info to socket
-
-            # if progress:
-            #     progress.session.load()
-            #     progress.session['error'] = True
-            #     progress.session['error_msg'] = "Batch population failed: {} - {}".format(error.__class__.__name__, error)
-            #     progress.session.save()
+            # TODO: write minimal error info to socket
+            if progress:
+                progress.session.load()
+                progress.session['error'] = True
+                progress.session['error_msg'] = (
+                    "{} of '{}' batch failed (see logs for more info)").format(
+                        handler_action, self.handler.batch_key)
+                progress.session.save()
 
             return
 
@@ -1374,49 +1275,6 @@ class BatchMasterView(MasterView):
         self.request.session.flash("Invalid request: {}".format(form.make_deform_form().error), 'error')
         return self.redirect(self.get_action_url('view', batch))
 
-    def mobile_execute(self):
-        """
-        Mobile view which can prompt user for execution options if applicable,
-        and/or execute a batch.  For now this is done in a "blocking" fashion,
-        i.e. no progress bar.
-        """
-        batch = self.get_instance()
-        model_title = self.get_model_title()
-        instance_title = self.get_instance_title(batch)
-        view_url = self.get_action_url('view', batch, mobile=True)
-        self.executing = True
-        form = self.make_execute_form(batch)
-        if form.validate(newstyle=True):
-            kwargs = dict(form.validated)
-
-            # cache options to use as defaults next time
-            for key, value in form.validated.items():
-                self.request.session['batch.{}.execute_option.{}'.format(batch.batch_key, key)] = value
-
-            try:
-                result = self.handler.execute(batch, user=self.request.user, **kwargs)
-            except Exception as err:
-                log.exception("failed to execute %s %s", model_title, batch.id_str)
-                self.request.session.flash(self.execute_error_message(err), 'error')
-            else:
-                if result:
-                    batch.executed = datetime.datetime.utcnow()
-                    batch.executed_by = self.request.user
-                    self.request.session.flash("{} was executed: {}".format(model_title, instance_title))
-                else:
-                    log.error("not sure why, but failed to execute %s %s: %s", model_title, batch.id_str, batch)
-                    self.request.session.flash("Failed to execute {}: {}".format(model_title, err), 'error')
-            return self.redirect(view_url)
-
-        form.mobile = True
-        form.submit_label = "Execute"
-        form.cancel_url = view_url
-        return self.render_to_response('execute', {
-            'form': form,
-            'instance_title': instance_title,
-            'instance_url': view_url,
-        }, mobile=True)
-
     def execute_error_message(self, error):
         return "Batch execution failed: {}".format(simple_error(error))
 
@@ -1576,7 +1434,6 @@ class BatchMasterView(MasterView):
         permission_prefix = cls.get_permission_prefix()
         model_title = cls.get_model_title()
         model_title_plural = cls.get_model_title_plural()
-        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # TODO: currently must do this here (in addition to `_defaults()` or
         # else the perm group label will not display correctly...
@@ -1635,18 +1492,6 @@ class BatchMasterView(MasterView):
         config.add_view(cls, attr='toggle_complete', route_name='{}.toggle_complete'.format(route_prefix),
                         permission='{}.edit'.format(permission_prefix))
 
-        # mobile mark complete
-        if legacy_mobile:
-            config.add_route('mobile.{}.mark_complete'.format(route_prefix), '/mobile{}/{{{}}}/mark-complete'.format(url_prefix, model_key))
-            config.add_view(cls, attr='mobile_mark_complete', route_name='mobile.{}.mark_complete'.format(route_prefix),
-                            permission='{}.edit'.format(permission_prefix))
-
-        # mobile mark pending
-        if legacy_mobile:
-            config.add_route('mobile.{}.mark_pending'.format(route_prefix), '/mobile{}/{{{}}}/mark-pending'.format(url_prefix, model_key))
-            config.add_view(cls, attr='mobile_mark_pending', route_name='mobile.{}.mark_pending'.format(route_prefix),
-                            permission='{}.edit'.format(permission_prefix))
-
         # refresh multiple batches (results)
         if cls.results_refreshable:
             config.add_route('{}.refresh_results'.format(route_prefix), '{}/refresh-results'.format(url_prefix),
@@ -1709,33 +1554,3 @@ class UploadWorksheet(colander.Schema):
 class ToggleComplete(colander.MappingSchema):
 
     complete = colander.SchemaNode(colander.Boolean())
-
-
-class MobileBatchStatusFilter(grids.filters.MobileFilter):
-
-    value_choices = ['pending', 'complete', 'executed', 'all']
-
-    def __init__(self, model_class, key, **kwargs):
-        self.model_class = model_class
-        super(MobileBatchStatusFilter, self).__init__(key, **kwargs)
-
-    def filter_equal(self, query, value):
-
-        if value == 'pending':
-            return query.filter(self.model_class.executed == None)\
-                        .filter(sa.or_(
-                            self.model_class.complete == None,
-                            self.model_class.complete == False))
-
-        if value == 'complete':
-            return query.filter(self.model_class.executed == None)\
-                        .filter(self.model_class.complete == True)
-
-        if value == 'executed':
-            return query.filter(self.model_class.executed != None)
-
-        return query
-
-    def iter_choices(self):
-        for value in self.value_choices:
-            yield value, prettify(value)
