@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -35,7 +35,6 @@ import six
 from rattail import pod
 from rattail.db import model
 from rattail.db.util import make_full_description
-from rattail.time import localtime
 from rattail.gpc import GPC
 from rattail.util import pretty_quantity, OrderedDict
 
@@ -63,8 +62,6 @@ class InventoryBatchView(BatchMasterView):
     index_title = "Inventory"
     rows_creatable = True
     bulk_deletable = True
-    mobile_creatable = True
-    mobile_rows_creatable = True
 
     # set to True for the UI to "prefer" case amounts, as opposed to unit
     prefer_cases = False
@@ -101,15 +98,6 @@ class InventoryBatchView(BatchMasterView):
         'executed_by',
     ]
 
-    mobile_form_fields = [
-        'mode',
-        'reason_code',
-        'rowcount',
-        'complete',
-        'executed',
-        'executed_by',
-    ]
-
     model_row_class = model.InventoryBatchRow
     rows_editable = True
 
@@ -160,13 +148,6 @@ class InventoryBatchView(BatchMasterView):
         # total_cost
         g.set_type('total_cost', 'currency')
 
-    def render_mobile_listitem(self, batch, i):
-        return "({}) {} rows - {}, {}".format(
-            batch.id_str,
-            "?" if batch.rowcount is None else batch.rowcount,
-            batch.created_by,
-            localtime(self.request.rattail_config, batch.created, from_utc=True).strftime('%Y-%m-%d'))
-
     def mutable_batch(self, batch):
         return not batch.executed and not batch.complete and batch.mode != self.enum.INVENTORY_MODE_ZERO_ALL
 
@@ -397,56 +378,6 @@ class InventoryBatchView(BatchMasterView):
             data['image_url'] = pod.get_image_url(self.rattail_config, product.upc)
         return data
 
-    def configure_mobile_form(self, f):
-        super(InventoryBatchView, self).configure_mobile_form(f)
-        batch = f.model_instance
-
-        # mode
-        modes = self.get_available_modes()
-        f.set_enum('mode', modes)
-        mode_values = [(k, v) for k, v in sorted(modes.items())]
-        f.set_widget('mode', forms.widgets.PlainSelectWidget(values=mode_values))
-
-        # complete
-        if self.creating or batch.executed or not batch.complete:
-            f.remove_field('complete')
-
-        # rowcount
-        if self.viewing and not batch.executed and not batch.complete:
-            f.remove_field('rowcount')
-
-    # TODO: this view can create new rows, with only a GET query.  that should
-    # probably be changed to require POST; for now we just require the "create
-    # batch row" perm and call it good..
-    def mobile_row_from_upc(self):
-        """
-        Locate and/or create a row within the batch, according to the given
-        product UPC, then redirect to the row view page.
-        """
-        batch = self.get_instance()
-        row = None
-        raw_entry = self.request.GET.get('upc', '')
-        entry = raw_entry.strip()
-        entry = re.sub(r'\D', '', entry)
-        if entry:
-
-            if len(entry) <= 14:
-                row = self.add_row_for_upc(batch, entry, warn_if_present=True)
-                if not row:
-                    self.request.session.flash("Product not found: {}".format(entry), 'error')
-                    return self.redirect(self.get_action_url('view', batch, mobile=True))
-
-            else:
-                self.request.session.flash("UPC has too many digits ({}): {}".format(len(entry), entry), 'error')
-                return self.redirect(self.get_action_url('view', batch, mobile=True))
-
-        else:
-            self.request.session.flash("Product not found: {}".format(raw_entry), 'error')
-            return self.redirect(self.get_action_url('view', batch, mobile=True))
-
-        self.Session.flush()
-        return self.redirect(self.mobile_row_route_url('view', uuid=row.batch_uuid, row_uuid=row.uuid))
-
     def add_row_for_upc(self, batch, entry, warn_if_present=False):
         """
         Add a row to the batch for the given UPC, if applicable.
@@ -467,76 +398,13 @@ class InventoryBatchView(BatchMasterView):
         kwargs['product_image_url'] = pod.get_image_url(self.rattail_config, row.upc)
         return kwargs
 
-    def get_batch_kwargs(self, batch, mobile=False):
-        kwargs = super(InventoryBatchView, self).get_batch_kwargs(batch, mobile=False)
+    def get_batch_kwargs(self, batch, **kwargs):
+        kwargs = super(InventoryBatchView, self).get_batch_kwargs(batch, **kwargs)
         kwargs['mode'] = batch.mode
         kwargs['complete'] = False
         kwargs['reason_code'] = batch.reason_code
         return kwargs
 
-    def get_mobile_row_data(self, batch):
-        # we want newest on top, for inventory batch rows
-        return self.get_row_data(batch)\
-                   .order_by(self.model_row_class.sequence.desc())
-
-    # TODO: ugh, the hackiness.  needs a refactor fo sho
-    def mobile_view_row(self):
-        """
-        Mobile view for inventory batch rows.  Note that this also handles
-        updating a row...ugh.
-        """
-        self.viewing = True
-        row = self.get_row_instance()
-        batch = self.get_parent(row)
-        form = self.make_mobile_row_form(row)
-
-        allow_cases = self.allow_cases(batch)
-        unit_uom = 'LB' if row.product and row.product.weighed else 'EA'
-        if row.cases and allow_cases:
-            uom = 'CS'
-        elif row.units:
-            uom = unit_uom
-        elif row.case_quantity and allow_cases and self.prefer_cases:
-            uom = 'CS'
-        else:
-            uom = unit_uom
-
-        context = {
-            'row': row,
-            'batch': batch,
-            'instance': row,
-            'instance_title': self.get_row_instance_title(row),
-            'parent_model_title': self.get_model_title(),
-            'parent_title': self.get_instance_title(batch),
-            'parent_url': self.get_action_url('view', batch, mobile=True),
-            'product_image_url': pod.get_image_url(self.rattail_config, row.upc),
-            'form': form,
-            'allow_cases': allow_cases,
-            'unit_uom': unit_uom,
-            'uom': uom,
-        }
-
-        if self.request.has_perm('{}.edit_row'.format(self.get_permission_prefix())):
-            schema = InventoryForm().bind(session=self.Session())
-            update_form = forms.Form(schema=schema, request=self.request)
-            if update_form.validate(newstyle=True):
-                row = self.Session.query(model.InventoryBatchRow).get(update_form.validated['row'])
-                cases = update_form.validated['cases']
-                units = update_form.validated['units']
-                if cases is not colander.null:
-                    row.cases = cases
-                    row.units = None
-                elif units is not colander.null:
-                    row.cases = None
-                    row.units = units
-                else:
-                    raise NotImplementedError
-                self.handler.refresh_row(row)
-                route_prefix = self.get_route_prefix()
-                return self.redirect(self.request.route_url('mobile.{}.view'.format(route_prefix), uuid=batch.uuid))
-
-        return self.render_to_response('view_row', context, mobile=True)
-
     def get_row_instance_title(self, row):
         if row.upc:
             return row.upc.pretty()
@@ -569,12 +437,6 @@ class InventoryBatchView(BatchMasterView):
         if row.status_code == row.STATUS_PRODUCT_NOT_FOUND:
             return 'warning'
 
-    def render_mobile_row_listitem(self, row, i):
-        description = row.product.full_description if row.product else row.description
-        unit_uom = 'LB' if row.product and row.product.weighed else 'EA'
-        qty = "{} {}".format(pretty_quantity(row.cases or row.units), 'CS' if row.cases else unit_uom)
-        return "({}) {} - {}".format(row.upc.pretty(), description, qty)
-
     def configure_row_form(self, f):
         super(InventoryBatchView, self).configure_row_form(f)
         row = f.model_instance
@@ -633,7 +495,6 @@ class InventoryBatchView(BatchMasterView):
         route_prefix = cls.get_route_prefix()
         url_prefix = cls.get_url_prefix()
         permission_prefix = cls.get_permission_prefix()
-        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # we need batch handler to determine available permissions
         factory = cls.get_handler_factory(rattail_config)
@@ -654,38 +515,6 @@ class InventoryBatchView(BatchMasterView):
         config.add_view(cls, attr='desktop_lookup', route_name='{}.desktop_lookup'.format(route_prefix),
                         renderer='json', permission='{}.create_row'.format(permission_prefix))
 
-        # mobile - make new row from UPC
-        if legacy_mobile:
-            config.add_route('mobile.{}.row_from_upc'.format(route_prefix), '/mobile{}/{{{}}}/row-from-upc'.format(url_prefix, model_key))
-            config.add_view(cls, attr='mobile_row_from_upc', route_name='mobile.{}.row_from_upc'.format(route_prefix),
-                            permission='{}.create_row'.format(permission_prefix))
-
-
-# TODO: this is a stopgap measure to fix an obvious bug, which exists when the
-# session is not provided by the view at runtime (i.e. when it was instead
-# being provided by the type instance, which was created upon app startup).
-@colander.deferred
-def valid_inventory_batch_row(node, kw):
-    session = kw['session']
-    def validate(node, value):
-        row = session.query(model.InventoryBatchRow).get(value)
-        if not row:
-            raise colander.Invalid(node, "Batch row not found")
-        if row.batch.executed:
-            raise colander.Invalid(node, "Batch has already been executed")
-        return row.uuid
-    return validate
-
-
-class InventoryForm(colander.MappingSchema):
-
-    row = colander.SchemaNode(colander.String(),
-                              validator=valid_inventory_batch_row)
-
-    cases = colander.SchemaNode(colander.Decimal(), missing=colander.null)
-
-    units = colander.SchemaNode(colander.Decimal(), missing=colander.null)
-
 
 # TODO: this is a stopgap measure to fix an obvious bug, which exists when the
 # session is not provided by the view at runtime (i.e. when it was instead
