@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -138,11 +138,11 @@ class LabelBatchView(BatchMasterView):
                 f.set_label('label_profile_uuid', "Label Profile")
 
     def render_handheld_batches(self, label_batch, field):
-        items = ''
+        items = []
         for handheld in label_batch._handhelds:
             text = handheld.handheld.id_str
             url = self.request.route_url('batch.handheld.view', uuid=handheld.handheld_uuid)
-            items += HTML.tag('li', c=tags.link_to(text, url))
+            items.append(HTML.tag('li', c=[tags.link_to(text, url)]))
         return HTML.tag('ul', c=items)
 
     def configure_row_grid(self, g):
