@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -171,8 +171,8 @@ class PricingBatchView(BatchMasterView):
             if self.request.POST.get('auto_generate_from_srp_breach') == 'true':
                 f.set_required('input_filename', False)
 
-    def get_batch_kwargs(self, batch, mobile=False):
-        kwargs = super(PricingBatchView, self).get_batch_kwargs(batch, mobile=mobile)
+    def get_batch_kwargs(self, batch, **kwargs):
+        kwargs = super(PricingBatchView, self).get_batch_kwargs(batch, **kwargs)
         kwargs['min_diff_threshold'] = batch.min_diff_threshold
         kwargs['min_diff_percent'] = batch.min_diff_percent
         kwargs['calculate_for_manual'] = batch.calculate_for_manual
@@ -199,6 +199,8 @@ class PricingBatchView(BatchMasterView):
         g.set_filter('vendor_id', model.Vendor.id)
         g.set_renderer('vendor_id', self.render_vendor_id)
 
+        g.set_renderer('subdepartment_number', self.render_subdepartment_number)
+
         g.set_type('old_price', 'currency')
         g.set_type('new_price', 'currency')
         g.set_type('price_diff', 'currency')
@@ -213,6 +215,13 @@ class PricingBatchView(BatchMasterView):
             return ""
         return vendor_id
 
+    def render_subdepartment_number(self, row, field):
+        if row.subdepartment_number:
+            if row.subdepartment_name:
+                return HTML.tag('span', title=row.subdepartment_name,
+                                c=six.text_type(row.subdepartment_number))
+            return row.subdepartment_number
+
     def render_true_margin(self, row, field):
         margin = row.true_margin
         if margin:
