@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -45,35 +45,41 @@ from tailbone.views.batch import FileBatchMasterView
 log = logging.getLogger(__name__)
 
 
-class VendorCatalogsView(FileBatchMasterView):
+class VendorCatalogView(FileBatchMasterView):
     """
     Master view for vendor catalog batches.
     """
-    model_class = model.VendorCatalog
-    model_row_class = model.VendorCatalogRow
+    model_class = model.VendorCatalogBatch
+    model_row_class = model.VendorCatalogBatchRow
     default_handler_spec = 'rattail.batch.vendorcatalog:VendorCatalogHandler'
+    route_prefix = 'vendorcatalogs'
     url_prefix = '/vendors/catalogs'
     template_prefix = '/batch/vendorcatalog'
     editable = False
     rows_bulk_deletable = True
 
+    labels = {
+        'vendor_id': "Vendor ID",
+    }
+
     grid_columns = [
         'id',
         'vendor',
-        'effective',
+        'description',
         'filename',
         'rowcount',
         'created',
-        'created_by',
         'executed',
     ]
 
     form_fields = [
         'id',
+        'description',
         'vendor',
         'filename',
         'future',
         'effective',
+        'notes',
         'created',
         'created_by',
         'rowcount',
@@ -105,6 +111,7 @@ class VendorCatalogsView(FileBatchMasterView):
         'brand_name',
         'description',
         'size',
+        'is_preferred_vendor',
         'old_vendor_code',
         'vendor_code',
         'old_case_size',
@@ -132,7 +139,7 @@ class VendorCatalogsView(FileBatchMasterView):
         return self.parsers
 
     def configure_grid(self, g):
-        super(VendorCatalogsView, self).configure_grid(g)
+        super(VendorCatalogView, self).configure_grid(g)
         g.joiners['vendor'] = lambda q: q.join(model.Vendor)
         g.filters['vendor'] = g.make_filter('vendor', model.Vendor.name,
                                             default_active=True, default_verb='contains')
@@ -141,15 +148,12 @@ class VendorCatalogsView(FileBatchMasterView):
         g.set_link('vendor')
         g.set_link('filename')
 
-    def get_instance_title(self, batch):
-        return six.text_type(batch.vendor)
-
     def configure_form(self, f):
-        super(VendorCatalogsView, self).configure_form(f)
+        super(VendorCatalogView, self).configure_form(f)
 
         # vendor
         f.set_renderer('vendor', self.render_vendor)
-        if self.creating:
+        if self.creating and 'vendor' in f:
             f.replace('vendor', 'vendor_uuid')
             f.set_node('vendor_uuid', colander.String())
             vendor_display = ""
@@ -168,36 +172,37 @@ class VendorCatalogsView(FileBatchMasterView):
         # filename
         f.set_label('filename', "Catalog File")
 
+        # parser_key
         if self.creating:
-
-            f.set_fields([
-                'filename',
-                'parser_key',
-                'vendor_uuid',
-                'future',
-            ])
-
-            parser_values = [(p.key, p.display) for p in self.get_parsers()]
-            parser_values.insert(0, ('', "(please choose)"))
-            f.set_widget('parser_key', dfwidget.SelectWidget(values=parser_values))
+            if 'parser_key' not in f:
+                f.insert_after('filename', 'parser_key')
+            values = [(p.key, p.display) for p in self.get_parsers()]
+            values.insert(0, ('', "(please choose)"))
+            f.set_widget('parser_key', dfwidget.SelectWidget(values=values))
             f.set_label('parser_key', "File Type")
 
         # effective
-        if not self.creating:
+        if self.creating:
+            f.remove('effective')
+        else:
             f.set_readonly('effective')
 
     def get_batch_kwargs(self, batch):
-        kwargs = super(VendorCatalogsView, self).get_batch_kwargs(batch)
+        kwargs = super(VendorCatalogView, self).get_batch_kwargs(batch)
         kwargs['parser_key'] = batch.parser_key
         if batch.vendor:
             kwargs['vendor'] = batch.vendor
         elif batch.vendor_uuid:
             kwargs['vendor_uuid'] = batch.vendor_uuid
+        if batch.vendor_id:
+            kwargs['vendor_id'] = batch.vendor_id
+        if batch.vendor_name:
+            kwargs['vendor_name'] = batch.vendor_name
         kwargs['future'] = batch.future
         return kwargs
 
     def configure_row_grid(self, g):
-        super(VendorCatalogsView, self).configure_row_grid(g)
+        super(VendorCatalogView, self).configure_row_grid(g)
         batch = self.get_instance()
 
         # starts
@@ -226,12 +231,14 @@ class VendorCatalogsView(FileBatchMasterView):
                                row.STATUS_UPDATE_COST, # TODO: deprecate/remove this one
                                row.STATUS_CHANGE_VENDOR_ITEM_CODE,
                                row.STATUS_CHANGE_CASE_SIZE,
-                               row.STATUS_CHANGE_COST):
+                               row.STATUS_CHANGE_COST,
+                               row.STATUS_CHANGE_PRODUCT):
             return 'notice'
 
     def configure_row_form(self, f):
-        super(VendorCatalogsView, self).configure_row_form(f)
+        super(VendorCatalogView, self).configure_row_form(f)
         f.set_renderer('product', self.render_product)
+        f.set_type('upc', 'gpc')
         f.set_type('discount_percent', 'percent')
 
     def template_kwargs_create(self, **kwargs):
@@ -251,6 +258,9 @@ class VendorCatalogsView(FileBatchMasterView):
         kwargs['parsers'] = parsers
         return kwargs
 
+# TODO: deprecate / remove this
+VendorCatalogsView = VendorCatalogView
+
 
 def includeme(config):
-    VendorCatalogsView.defaults(config)
+    VendorCatalogView.defaults(config)
