@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -31,7 +31,7 @@ from rattail.db import model
 from tailbone.views import MasterView, AutocompleteView
 
 
-class BrandsView(MasterView):
+class BrandView(MasterView):
     """
     Master view for the Brand class.
     """
@@ -59,7 +59,7 @@ class BrandsView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(BrandsView, self).configure_grid(g)
+        super(BrandView, self).configure_grid(g)
 
         # name
         g.filters['name'].default_active = True
@@ -90,6 +90,9 @@ class BrandsView(MasterView):
         self.Session.flush()
         self.Session.delete(removing)
 
+# TODO: deprecate / remove this
+BrandsView = BrandView
+
 
 class BrandsAutocomplete(AutocompleteView):
 
@@ -104,4 +107,4 @@ def includeme(config):
     config.add_view(BrandsAutocomplete, route_name='brands.autocomplete',
                     renderer='json', permission='brands.list')
 
-    BrandsView.defaults(config)
+    BrandView.defaults(config)
