@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,7 +32,7 @@ from tailbone import forms
 from tailbone.views import MasterView
 
 
-class CategoriesView(MasterView):
+class CategoryView(MasterView):
     """
     Master view for the Category class.
     """
@@ -55,7 +55,7 @@ class CategoriesView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(CategoriesView, self).configure_grid(g)
+        super(CategoryView, self).configure_grid(g)
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
 
@@ -68,7 +68,7 @@ class CategoriesView(MasterView):
         g.set_link('name')
 
     def get_xlsx_fields(self):
-        fields = super(CategoriesView, self).get_xlsx_fields()
+        fields = super(CategoryView, self).get_xlsx_fields()
         fields.extend([
             'department_number',
             'department_name',
@@ -76,7 +76,7 @@ class CategoriesView(MasterView):
         return fields
 
     def get_xlsx_row(self, category, fields):
-        row = super(CategoriesView, self).get_xlsx_row(category, fields)
+        row = super(CategoryView, self).get_xlsx_row(category, fields)
         dept = category.department
         if dept:
             row['department_number'] = dept.number
@@ -87,7 +87,7 @@ class CategoriesView(MasterView):
         return row
 
     def configure_form(self, f):
-        super(CategoriesView, self).configure_form(f)
+        super(CategoryView, self).configure_form(f)
 
         # department
         if self.creating or self.editing:
@@ -106,6 +106,9 @@ class CategoriesView(MasterView):
         return [(dept.uuid, "{} {}".format(dept.number, dept.name))
                 for dept in departments]
 
+# TODO: deprecate / remove this
+CategoriesView = CategoryView
+
 
 def includeme(config):
-    CategoriesView.defaults(config)
+    CategoryView.defaults(config)
