@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -43,14 +43,13 @@ from tailbone.views import MasterView, AutocompleteView
 from rattail.db import model
 
 
-class CustomersView(MasterView):
+class CustomerView(MasterView):
     """
     Master view for the Customer class.
     """
     model_class = model.Customer
     is_contact = True
     has_versions = True
-    supports_mobile = True
     people_detachable = True
     touchable = True
 
@@ -95,22 +94,8 @@ class CustomersView(MasterView):
         'members',
     ]
 
-    mobile_form_fields = [
-        'id',
-        'name',
-        'default_phone',
-        'default_email',
-        'default_address',
-        'email_preference',
-        'wholesale',
-        'active_in_pos',
-        'active_in_pos_sticky',
-        'people',
-        'groups',
-    ]
-
     def configure_grid(self, g):
-        super(CustomersView, self).configure_grid(g)
+        super(CustomerView, self).configure_grid(g)
 
         # name
         g.filters['name'].default_active = True
@@ -154,13 +139,9 @@ class CustomersView(MasterView):
         g.set_link('person')
         g.set_link('email')
 
-    def get_mobile_data(self, session=None):
-        # TODO: hacky!
-        return self.get_data(session=session).order_by(model.Customer.name)
-
     def get_instance(self):
         try:
-            instance = super(CustomersView, self).get_instance()
+            instance = super(CustomerView, self).get_instance()
         except HTTPNotFound:
             pass
         else:
@@ -189,7 +170,7 @@ class CustomersView(MasterView):
         raise HTTPNotFound
 
     def configure_common_form(self, f):
-        super(CustomersView, self).configure_common_form(f)
+        super(CustomerView, self).configure_common_form(f)
         customer = f.model_instance
         permission_prefix = self.get_permission_prefix()
 
@@ -252,7 +233,7 @@ class CustomersView(MasterView):
             f.set_readonly('groups')
 
     def configure_form(self, f):
-        super(CustomersView, self).configure_form(f)
+        super(CustomerView, self).configure_form(f)
         customer = f.model_instance
         permission_prefix = self.get_permission_prefix()
 
@@ -303,8 +284,7 @@ class CustomersView(MasterView):
         items = []
         for person in people:
             text = six.text_type(person)
-            route = '{}people.view'.format('mobile.' if self.mobile else '')
-            url = self.request.route_url(route, uuid=person.uuid)
+            url = self.request.route_url('people.view', uuid=person.uuid)
             link = tags.link_to(text, url)
             items.append(HTML.tag('li', c=[link]))
         return HTML.tag('ul', c=items)
@@ -406,6 +386,9 @@ class CustomersView(MasterView):
             config.add_view(cls, attr='detach_person', route_name='{}.detach_person'.format(route_prefix),
                             permission='{}.detach_person'.format(permission_prefix))
 
+# TODO: deprecate / remove this
+CustomersView = CustomerView
+
 
 # # TODO: this is referenced by some custom apps, but should be moved??
 # def unique_id(value, field):
@@ -492,4 +475,4 @@ def includeme(config):
     config.add_view(customer_info, route_name='customer.info',
                     renderer='json', permission='customers.view')
 
-    CustomersView.defaults(config)
+    CustomerView.defaults(config)
