@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -37,7 +37,7 @@ from tailbone.views import MasterView
 log = logging.getLogger(__name__)
 
 
-class DataSyncChangesView(MasterView):
+class DataSyncChangeView(MasterView):
     """
     Master view for the DataSyncChange model.
     """
@@ -64,7 +64,7 @@ class DataSyncChangesView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(DataSyncChangesView, self).configure_grid(g)
+        super(DataSyncChangeView, self).configure_grid(g)
 
         # batch_sequence
         g.set_label('batch_sequence', "Batch Seq.")
@@ -89,30 +89,23 @@ class DataSyncChangesView(MasterView):
                 self.request.session.flash("DataSync daemon could not be restarted; result was: {}".format(result), 'error')
         return self.redirect(self.request.get_referrer(default=self.request.route_url('datasyncchanges')))
 
-    def mobile_index(self):
-        return {}
-
     @classmethod
     def defaults(cls, config):
         rattail_config = config.registry.settings.get('rattail_config')
-        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # fix permission group title
         config.add_tailbone_permission_group('datasync', label="DataSync")
 
         # restart datasync
         config.add_tailbone_permission('datasync', 'datasync.restart', label="Restart DataSync Daemon")
-        # desktop
         config.add_route('datasync.restart', '/datasync/restart')
         config.add_view(cls, attr='restart', route_name='datasync.restart', permission='datasync.restart')
-        # mobile
-        if legacy_mobile:
-            config.add_route('datasync.mobile', '/mobile/datasync/')
-            config.add_view(cls, attr='mobile_index', route_name='datasync.mobile',
-                            permission='datasync.restart', renderer='/mobile/datasync.mako')
 
         cls._defaults(config)
 
+# TODO: deprecate / remove this
+DataSyncChangesView = DataSyncChangeView
+
 
 def includeme(config):
-    DataSyncChangesView.defaults(config)
+    DataSyncChangeView.defaults(config)
