@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -36,7 +36,7 @@ from tailbone import grids
 from tailbone.views import MasterView, AutocompleteView
 
 
-class DepartmentsView(MasterView):
+class DepartmentView(MasterView):
     """
     Master view for the Department class.
     """
@@ -58,10 +58,11 @@ class DepartmentsView(MasterView):
         'product',
         'personnel',
         'exempt_from_gross_sales',
+        'allow_product_deletions',
     ]
 
     def configure_grid(self, g):
-        super(DepartmentsView, self).configure_grid(g)
+        super(DepartmentView, self).configure_grid(g)
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
         g.set_sort_defaults('number')
@@ -71,7 +72,7 @@ class DepartmentsView(MasterView):
         g.set_link('name')
 
     def configure_form(self, f):
-        super(DepartmentsView, self).configure_form(f)
+        super(DepartmentView, self).configure_form(f)
         f.remove_field('subdepartments')
         f.remove_field('employees')
         f.set_type('product', 'boolean')
@@ -144,6 +145,9 @@ class DepartmentsView(MasterView):
 
         cls._defaults(config)
 
+# TODO: deprecate / remove this
+DepartmentsView = DepartmentView
+
 
 class DepartmentsAutocomplete(AutocompleteView):
 
@@ -158,4 +162,4 @@ def includeme(config):
     config.add_view(DepartmentsAutocomplete, route_name='departments.autocomplete',
                     renderer='json', permission='departments.list')
 
-    DepartmentsView.defaults(config)
+    DepartmentView.defaults(config)
