@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -31,7 +31,7 @@ from rattail.db import model
 from tailbone.views import MasterView
 
 
-class FamiliesView(MasterView):
+class FamilyView(MasterView):
     """
     Master view for the Family class.
     """
@@ -52,11 +52,14 @@ class FamiliesView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(FamiliesView, self).configure_grid(g)
+        super(FamilyView, self).configure_grid(g)
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
         g.set_sort_defaults('code')
 
+# TODO: deprecate / remove this
+FamiliesView = FamilyView
+
 
 def includeme(config):
-    FamiliesView.defaults(config)
+    FamilyView.defaults(config)
