@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -44,7 +44,7 @@ from tailbone import forms, grids
 from tailbone.views import MasterView, AutocompleteView
 
 
-class PeopleView(MasterView):
+class PersonView(MasterView):
     """
     Master view for the Person class.
     """
@@ -53,7 +53,6 @@ class PeopleView(MasterView):
     route_prefix = 'people'
     touchable = True
     has_versions = True
-    supports_mobile = True
     bulk_deletable = True
     is_contact = True
     manage_notes_from_profile_view = False
@@ -85,21 +84,20 @@ class PeopleView(MasterView):
         'users',
     ]
 
-    mobile_form_fields = [
+    mergeable = True
+    merge_additive_fields = [
+        'usernames',
+        'member_uuids',
+    ]
+    merge_fields = merge_additive_fields + [
+        'uuid',
         'first_name',
-        'middle_name',
         'last_name',
         'display_name',
-        'phone',
-        'email',
-        'address',
-        'employee',
-        'customers',
-        'users',
     ]
 
     def configure_grid(self, g):
-        super(PeopleView, self).configure_grid(g)
+        super(PersonView, self).configure_grid(g)
 
         g.joiners['email'] = lambda q: q.outerjoin(model.PersonEmailAddress, sa.and_(
             model.PersonEmailAddress.parent_uuid == model.Person.uuid,
@@ -121,6 +119,10 @@ class PeopleView(MasterView):
         g.filters['last_name'].default_active = True
         g.filters['last_name'].default_verb = 'contains'
 
+        g.set_joiner('employee_status', lambda q: q.outerjoin(model.Employee))
+        g.set_filter('employee_status', model.Employee.status,
+                     value_enum=self.enum.EMPLOYEE_STATUS)
+
         g.sorters['email'] = lambda q, d: q.order_by(getattr(model.PersonEmailAddress.address, d)())
         g.sorters['phone'] = lambda q, d: q.order_by(getattr(model.PersonPhoneNumber.number, d)())
 
@@ -163,6 +165,37 @@ class PeopleView(MasterView):
             return True
         return not self.is_person_protected(person)
 
+    def objectify(self, form, data=None):
+        if data is None:
+            data = form.validated
+
+        # do normal create/update
+        person = super(PersonView, self).objectify(form, data)
+
+        # collect data from all name fields
+        names = {}
+        if 'first_name' in form:
+            names['first'] = data['first_name']
+        if 'middle_name' in form:
+            names['middle'] = data['middle_name']
+        if 'last_name' in form:
+            names['last'] = data['last_name']
+        if 'display_name' in form and 'display_name' not in form.readonly_fields:
+            names['full'] = data['display_name']
+
+        # TODO: why do we find colander.null values in data at this point?
+        # ugh, for now we must convert them
+        for key in names:
+            if names[key] is colander.null:
+                names[key] = None
+
+        # do explicit name update w/ common handler logic
+        app = self.get_rattail_app()
+        handler = app.get_people_handler()
+        handler.update_names(person, **names)
+
+        return person
+
     def delete_instance(self, person):
         """
         Supplements the default logic as follows:
@@ -180,7 +213,7 @@ class PeopleView(MasterView):
             customer._people.reorder()
 
         # continue with normal logic
-        super(PeopleView, self).delete_instance(person)
+        super(PersonView, self).delete_instance(person)
 
     def touch_instance(self, person):
         """
@@ -190,7 +223,7 @@ class PeopleView(MasterView):
         contact info record associated with them.
         """
         # touch person, as per usual
-        super(PeopleView, self).touch_instance(person)
+        super(PersonView, self).touch_instance(person)
 
         def touch(obj):
             change = model.Change()
@@ -212,7 +245,7 @@ class PeopleView(MasterView):
             touch(address)
 
     def configure_common_form(self, f):
-        super(PeopleView, self).configure_common_form(f)
+        super(PersonView, self).configure_common_form(f)
         person = f.model_instance
 
         f.set_label('display_name', "Full Name")
@@ -284,8 +317,7 @@ class PeopleView(MasterView):
                 text = "(#{}) {}".format(customer.number, text)
             elif customer.id:
                 text = "({}) {}".format(customer.id, text)
-            route = '{}customers.view'.format('mobile.' if self.mobile else '')
-            url = self.request.route_url(route, uuid=customer.uuid)
+            url = self.request.route_url('customers.view', uuid=customer.uuid)
             items.append(HTML.tag('li', c=[tags.link_to(text, url)]))
         return HTML.tag('ul', c=items)
 
@@ -333,6 +365,34 @@ class PeopleView(MasterView):
             (model.VendorContact, 'person_uuid'),
         ]
 
+    def get_merge_data(self, person):
+        return {
+            'uuid': person.uuid,
+            'first_name': person.first_name,
+            'last_name': person.last_name,
+            'display_name': person.display_name,
+            'usernames': [u.username for u in person.users],
+            'member_uuids': [m.uuid for m in person.members],
+        }
+
+    def merge_objects(self, removing, keeping):
+        """
+        Execute a merge operation on the two given person records.
+        """
+        # move Member records to final Person
+        for member in list(removing.members):
+            removing.members.remove(member)
+            keeping.members.append(member)
+
+        # move User records to final Person
+        for user in list(removing.users):
+            removing.users.remove(user)
+            keeping.users.append(user)
+
+        # delete unwanted Person
+        self.Session.delete(removing)
+        self.Session.flush()
+
     def view_profile(self):
         """
         View which exposes the "full profile" for a given person, i.e. all
@@ -725,6 +785,9 @@ class PeopleView(MasterView):
         config.add_view(cls, attr='make_user', route_name='{}.make_user'.format(route_prefix),
                         permission='users.create')
 
+# TODO: deprecate / remove this
+PeopleView = PersonView
+
 
 class PeopleAutocomplete(AutocompleteView):
 
@@ -843,5 +906,5 @@ def includeme(config):
     config.add_view(PeopleEmployeesAutocomplete, route_name='people.autocomplete.employees',
                     renderer='json', permission='people.list')
 
-    PeopleView.defaults(config)
+    PersonView.defaults(config)
     PersonNoteView.defaults(config)
