@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -40,7 +40,7 @@ from rattail.db import model, api, auth, Session as RattailSession
 from rattail.gpc import GPC
 from rattail.threads import Thread
 from rattail.exceptions import LabelPrintingError
-from rattail.util import load_object, pretty_quantity, OrderedDict
+from rattail.util import load_object, pretty_quantity, OrderedDict, simple_error
 from rattail.batch import get_batch_handler
 from rattail.time import localtime, make_utc
 
@@ -77,12 +77,11 @@ log = logging.getLogger(__name__)
 #         return query
 
 
-class ProductsView(MasterView):
+class ProductView(MasterView):
     """
     Master view for the Product class.
     """
     model_class = model.Product
-    supports_mobile = True
     has_versions = True
     results_downloadable_xlsx = True
 
@@ -157,8 +156,6 @@ class ProductsView(MasterView):
         'inventory_on_order',
     ]
 
-    mobile_form_fields = form_fields
-
     # These aliases enable the grid queries to filter products which may be
     # purchased from *any* vendor, and yet sort by only the "preferred" vendor
     # (since that's what shows up in the grid column).
@@ -171,7 +168,7 @@ class ProductsView(MasterView):
     CurrentPrice = orm.aliased(model.ProductPrice)
 
     def __init__(self, request):
-        super(ProductsView, self).__init__(request)
+        super(ProductView, self).__init__(request)
         self.print_labels = request.rattail_config.getbool('tailbone', 'products.print_labels', default=False)
 
     def query(self, session):
@@ -201,7 +198,7 @@ class ProductsView(MasterView):
         return query
 
     def configure_grid(self, g):
-        super(ProductsView, self).configure_grid(g)
+        super(ProductView, self).configure_grid(g)
 
         def join_vendor(q):
             return q.outerjoin(self.ProductVendorCost,
@@ -299,6 +296,7 @@ class ProductsView(MasterView):
         g.set_filter('regular_price', self.RegularPrice.price, label="Regular Price")
 
         g.set_label('current_price', "Cur. Price")
+        g.set_renderer('current_price', self.render_current_price_for_grid)
         g.set_joiner('current_price', lambda q: q.outerjoin(
             self.CurrentPrice, self.CurrentPrice.uuid == model.Product.current_price_uuid))
         g.set_sorter('current_price', self.CurrentPrice.price)
@@ -329,7 +327,6 @@ class ProductsView(MasterView):
         g.set_type('upc', 'gpc')
 
         g.set_renderer('regular_price', self.render_price)
-        g.set_renderer('current_price', self.render_price)
         g.set_renderer('on_hand', self.render_on_hand)
         g.set_renderer('on_order', self.render_on_order)
 
@@ -342,7 +339,7 @@ class ProductsView(MasterView):
         g.set_label('vendor', "Pref. Vendor")
 
     def configure_common_form(self, f):
-        super(ProductsView, self).configure_common_form(f)
+        super(ProductView, self).configure_common_form(f)
         product = f.model_instance
 
         # upc
@@ -475,6 +472,30 @@ class ProductsView(MasterView):
                     return "$ {:0.2f} / {}".format(price.pack_price, price.pack_multiple)
         return ""
         
+    def render_current_price_for_grid(self, product, field):
+        text = self.render_price(product, field)
+
+        price = product.current_price
+        if price:
+            app = self.get_rattail_app()
+
+            if price.starts:
+                starts = localtime(self.rattail_config, price.starts, from_utc=True)
+                starts = app.render_date(starts.date())
+            else:
+                starts = "??"
+
+            if price.ends:
+                ends = localtime(self.rattail_config, price.ends, from_utc=True)
+                ends = app.render_date(ends.date())
+            else:
+                ends = "??"
+
+            return HTML.tag('span', c=text,
+                            title="{} thru {}".format(starts, ends))
+
+        return text
+
     def add_price_history_link(self, text, typ):
         if not self.rattail_config.versioning_enabled():
             return text
@@ -594,7 +615,7 @@ class ProductsView(MasterView):
             return ' '.join(classes)
 
     def get_xlsx_fields(self):
-        fields = super(ProductsView, self).get_xlsx_fields()
+        fields = super(ProductView, self).get_xlsx_fields()
 
         i = fields.index('department_uuid')
         fields.insert(i + 1, 'department_number')
@@ -640,7 +661,7 @@ class ProductsView(MasterView):
         return fields
 
     def get_xlsx_row(self, product, fields):
-        row = super(ProductsView, self).get_xlsx_row(product, fields)
+        row = super(ProductView, self).get_xlsx_row(product, fields)
 
         if 'upc' in fields and isinstance(row['upc'], GPC):
             row['upc'] = row['upc'].pretty()
@@ -710,7 +731,7 @@ class ProductsView(MasterView):
         raise httpexceptions.HTTPNotFound()
 
     def configure_form(self, f):
-        super(ProductsView, self).configure_form(f)
+        super(ProductView, self).configure_form(f)
         product = f.model_instance
 
         # department
@@ -862,6 +883,9 @@ class ProductsView(MasterView):
         else:
             f.set_readonly('brand')
 
+        # case_size
+        f.set_type('case_size', 'quantity')
+
         # status_code
         f.set_label('status_code', "Status")
 
@@ -877,7 +901,7 @@ class ProductsView(MasterView):
     def objectify(self, form, data=None):
         if data is None:
             data = form.validated
-        product = super(ProductsView, self).objectify(form, data=data)
+        product = super(ProductView, self).objectify(form, data=data)
 
         # regular_price_amount
         if (self.creating or self.editing) and 'regular_price_amount' in form.fields:
@@ -933,7 +957,7 @@ class ProductsView(MasterView):
             else:
                 code = pack.item_id
             text = "({}) {}".format(code, pack.full_description)
-            url = self.get_action_url('view', pack, mobile=self.mobile)
+            url = self.get_action_url('view', pack)
             links.append(tags.link_to(text, url))
 
         items = [HTML.tag('li', c=[link]) for link in links]
@@ -952,7 +976,7 @@ class ProductsView(MasterView):
             code = unit.item_id
 
         text = "({}) {}".format(code, unit.full_description)
-        url = self.get_action_url('view', unit, mobile=self.mobile)
+        url = self.get_action_url('view', unit)
         return tags.link_to(text, url)
 
     def render_current_price_ends(self, product, field):
@@ -1491,37 +1515,6 @@ class ProductsView(MasterView):
                                                 'instance_title': self.get_instance_title(instance),
                                                 'form': form})
 
-    def mobile_index(self):
-        """
-        Mobile "home" page for products
-        """
-        self.mobile = True
-        context = {
-            'quick_lookup': False,
-            'placeholder': "Enter {}".format(self.rattail_config.product_key_title()),
-            'quick_lookup_keyboard_wedge': True,
-        }
-        if self.rattail_config.getbool('rattail', 'products.mobile.quick_lookup', default=False):
-            context['quick_lookup'] = True
-        else:
-            self.listing = True
-            grid = self.make_mobile_grid()
-            context['grid'] = grid
-        return self.render_to_response('index', context, mobile=True)
-
-    def mobile_quick_lookup(self):
-        entry = self.request.POST['quick_entry'].strip()
-        provided = GPC(entry, calc_check_digit=False)
-        product = api.get_product_by_upc(self.Session(), provided)
-        if not product:
-            checked = GPC(entry, calc_check_digit='upc')
-            product = api.get_product_by_upc(self.Session(), checked)
-        if not product:
-            product = api.get_product_by_code(self.Session(), entry)
-        if not product:
-            raise self.notfound()
-        return self.redirect(self.get_action_url('view', product, mobile=True))
-
     def get_version_child_classes(self):
         return [
             (model.ProductCode, 'product_uuid'),
@@ -1583,10 +1576,20 @@ class ProductsView(MasterView):
         return {'product': data}
 
     def get_supported_batches(self):
-        return {
-            'labels': 'rattail.batch.labels:LabelBatchHandler',
-            'pricing': 'rattail.batch.pricing:PricingBatchHandler',
-        }
+        return OrderedDict([
+            ('labels', {
+                'spec': self.rattail_config.get('rattail.batch', 'labels.handler',
+                                                default='rattail.batch.labels:LabelBatchHandler'),
+            }),
+            ('pricing', {
+                'spec': self.rattail_config.get('rattail.batch', 'pricing.handler',
+                                                default='rattail.batch.pricing:PricingBatchHandler'),
+            }),
+            ('delproduct', {
+                'spec': self.rattail_config.get('rattail.batch', 'delproduct.handler',
+                                                default='rattail.batch.delproduct:DeleteProductBatchHandler'),
+            }),
+        ])
 
     def make_batch(self):
         """
@@ -1629,6 +1632,7 @@ class ProductsView(MasterView):
         if self.request.method == 'POST':
             if form.validate(newstyle=True):
                 data = form.validated
+                fully_validated = True
 
                 # collect general params
                 batch_key = data['batch_type']
@@ -1638,27 +1642,32 @@ class ProductsView(MasterView):
 
                 # collect batch-type-specific params
                 pform = params_forms.get(batch_key)
-                if pform and pform.validate(newstyle=True):
-                    pdata = pform.validated
-                    for field in pform.schema:
-                        param_name = pform.schema[field.name].param_name
-                        params[param_name] = pdata[field.name]
+                if pform:
+                    if pform.validate(newstyle=True):
+                        pdata = pform.validated
+                        for field in pform.schema:
+                            param_name = pform.schema[field.name].param_name
+                            params[param_name] = pdata[field.name]
+                    else:
+                        fully_validated = False
 
-                # TODO: should this be done elsewhere?
-                for name in params:
-                    if params[name] is colander.null:
-                        params[name] = None
+                if fully_validated:
 
-                handler = supported[batch_key]
-                products = self.get_products_for_batch(batch_key)
-                progress = self.make_progress('products.batch')
-                thread = Thread(target=self.make_batch_thread,
-                                args=(handler, self.request.user.uuid, products, params, progress))
-                thread.start()
-                return self.render_progress(progress, {
-                    'cancel_url': self.get_index_url(),
-                    'cancel_msg': "Batch creation was canceled.",
-                })
+                    # TODO: should this be done elsewhere?
+                    for name in params:
+                        if params[name] is colander.null:
+                            params[name] = None
+
+                    handler = supported[batch_key]
+                    products = self.get_products_for_batch(batch_key)
+                    progress = self.make_progress('products.batch')
+                    thread = Thread(target=self.make_batch_thread,
+                                    args=(handler, self.request.user.uuid, products, params, progress))
+                    thread.start()
+                    return self.render_progress(progress, {
+                        'cancel_url': self.get_index_url(),
+                        'cancel_msg': "Batch creation was canceled.",
+                    })
 
         return self.render_to_response('batch', {
             'form': form,
@@ -1689,6 +1698,17 @@ class ProductsView(MasterView):
             colander.SchemaNode(colander.Boolean(), name='calculate_for_manual'),
         )
 
+    def make_batch_params_schema_delproduct(self):
+        """
+        Return params schema for making a "delete products" batch.
+        """
+        return colander.SchemaNode(
+            colander.Mapping(),
+            colander.SchemaNode(colander.Integer(), name='inactivity_months',
+                                # TODO: probably should be configurable
+                                default=18),
+        )
+
     def make_batch_thread(self, handler, user_uuid, products, params, progress):
         """
         Threat target for making a batch from current products query.
@@ -1697,25 +1717,42 @@ class ProductsView(MasterView):
         user = session.query(model.User).get(user_uuid)
         assert user
         params['created_by'] = user
-        batch = handler.make_batch(session, **params)
-        batch.products = products.with_session(session).all()
-        handler.do_populate(batch, user, progress=progress)
+        try:
+            batch = handler.make_batch(session, **params)
+            batch.products = products.with_session(session).all()
+            handler.do_populate(batch, user, progress=progress)
 
-        session.commit()
-        session.refresh(batch)
-        session.close()
+        except Exception as error:
+            session.rollback()
+            log.exception("failed to make '%s' batch with params: %s",
+                          handler.batch_key, params)
+            session.close()
+            if progress:
+                progress.session.load()
+                progress.session['error'] = True
+                progress.session['error_msg'] = "Failed to make '{}' batch: {}".format(
+                    handler.batch_key, simple_error(error))
+                progress.session.save()
 
-        progress.session.load()
-        progress.session['complete'] = True
-        progress.session['success_url'] = self.get_batch_view_url(batch)
-        progress.session['success_msg'] = 'Batch has been created: {}'.format(batch)
-        progress.session.save()
+        else:
+            session.commit()
+            session.refresh(batch)
+            session.close()
+
+            if progress:
+                progress.session.load()
+                progress.session['complete'] = True
+                progress.session['success_url'] = self.get_batch_view_url(batch)
+                progress.session['success_msg'] = 'Batch has been created: {}'.format(batch)
+                progress.session.save()
 
     def get_batch_view_url(self, batch):
         if batch.batch_key == 'labels':
             return self.request.route_url('labels.batch.view', uuid=batch.uuid)
         if batch.batch_key == 'pricing':
             return self.request.route_url('batch.pricing.view', uuid=batch.uuid)
+        if batch.batch_key == 'delproduct':
+            return self.request.route_url('batch.delproduct.view', uuid=batch.uuid)
 
     @classmethod
     def defaults(cls, config):
@@ -1731,7 +1768,6 @@ class ProductsView(MasterView):
         template_prefix = cls.get_template_prefix()
         permission_prefix = cls.get_permission_prefix()
         model_title = cls.get_model_title()
-        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # print labels
         config.add_tailbone_permission('products', 'products.print_labels',
@@ -1772,10 +1808,8 @@ class ProductsView(MasterView):
                         renderer='json',
                         permission='{}.versions'.format(permission_prefix))
 
-        # mobile quick lookup
-        if legacy_mobile:
-            config.add_route('mobile.products.quick_lookup', '/mobile/products/quick-lookup')
-            config.add_view(cls, attr='mobile_quick_lookup', route_name='mobile.products.quick_lookup')
+# TODO: deprecate / remove this
+ProductsView = ProductView
 
 
 class ProductsAutocomplete(AutocompleteView):
@@ -1838,4 +1872,4 @@ def includeme(config):
     config.add_view(print_labels, route_name='products.print_labels',
                     renderer='json', permission='products.print_labels')
 
-    ProductsView.defaults(config)
+    ProductView.defaults(config)
