@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -51,12 +51,7 @@ class OrderingBatchView(PurchasingBatchView):
     model_title = "Ordering Batch"
     model_title_plural = "Ordering Batches"
     index_title = "Ordering"
-    mobile_creatable = True
     rows_editable = True
-    mobile_rows_creatable = True
-    mobile_rows_quickable = True
-    mobile_rows_editable = True
-    mobile_rows_deletable = True
     has_worksheet = True
 
     labels = {
@@ -86,21 +81,6 @@ class OrderingBatchView(PurchasingBatchView):
         'executed_by',
     ]
 
-    mobile_form_fields = [
-        'vendor',
-        'department',
-        'date_ordered',
-        'po_number',
-        'po_total',
-        'created',
-        'created_by',
-        'notes',
-        'status_code',
-        'complete',
-        'executed',
-        'executed_by',
-    ]
-
     row_labels = {
         'po_total_calculated': "PO Total",
     }
@@ -155,12 +135,14 @@ class OrderingBatchView(PurchasingBatchView):
 
     def configure_form(self, f):
         super(OrderingBatchView, self).configure_form(f)
+        batch = f.model_instance
 
         # purchase
-        f.remove_field('purchase')
+        if self.creating or not batch.executed or not batch.purchase:
+            f.remove_field('purchase')
 
-    def get_batch_kwargs(self, batch, mobile=False):
-        kwargs = super(OrderingBatchView, self).get_batch_kwargs(batch, mobile=mobile)
+    def get_batch_kwargs(self, batch, **kwargs):
+        kwargs = super(OrderingBatchView, self).get_batch_kwargs(batch, **kwargs)
         kwargs['ship_method'] = batch.ship_method
         kwargs['notes_to_vendor'] = batch.notes_to_vendor
         return kwargs
@@ -187,6 +169,89 @@ class OrderingBatchView(PurchasingBatchView):
                 if field not in editable_fields:
                     f.set_readonly(field)
 
+    def scanning_entry(self):
+        """
+        AJAX view to handle user entry/fetch input for "scanning" feature.
+        """
+        data = self.request.json_body
+        app = self.get_rattail_app()
+        prodder = app.get_products_handler()
+
+        batch = self.get_instance()
+        entry = data['entry']
+        row = self.handler.quick_entry(self.Session(), batch, entry)
+
+        uom = self.enum.UNIT_OF_MEASURE_EACH
+        if row.product and row.product.weighed:
+            uom = self.enum.UNIT_OF_MEASURE_POUND
+
+        cases_ordered = None
+        if row.cases_ordered:
+            cases_ordered = float(row.cases_ordered)
+
+        units_ordered = None
+        if row.units_ordered:
+            units_ordered = float(row.units_ordered)
+
+        po_case_cost = None
+        if row.po_unit_cost is not None:
+            po_case_cost = row.po_unit_cost * (row.case_quantity or 1)
+
+        product_url = None
+        if row.product_uuid:
+            product_url = self.request.route_url('products.view', uuid=row.product_uuid)
+
+        product_price = None
+        if row.product and row.product.regular_price:
+            product_price = row.product.regular_price.price
+
+        product_price_display = None
+        if product_price is not None:
+            product_price_display = app.render_currency(product_price)
+
+        return {
+            'ok': True,
+            'entry': entry,
+            'row': {
+                'uuid': row.uuid,
+                'item_id': row.item_id,
+                'upc_display': row.upc.pretty() if row.upc else None,
+                'brand_name': row.brand_name,
+                'description': row.description,
+                'size': row.size,
+                'unit_of_measure_display': self.enum.UNIT_OF_MEASURE[uom],
+                'case_quantity': float(row.case_quantity) if row.case_quantity is not None else None,
+                'cases_ordered': cases_ordered,
+                'units_ordered': units_ordered,
+                'po_unit_cost': float(row.po_unit_cost) if row.po_unit_cost is not None else None,
+                'po_unit_cost_display': app.render_currency(row.po_unit_cost),
+                'po_case_cost': float(po_case_cost) if po_case_cost is not None else None,
+                'po_case_cost_display': app.render_currency(po_case_cost),
+                'image_url': prodder.get_image_url(upc=row.upc),
+                'product_url': product_url,
+                'product_price_display': product_price_display,
+            },
+        }
+
+    def scanning_update(self):
+        """
+        AJAX view to handle row data updates for "scanning" feature.
+        """
+        data = self.request.json_body
+        batch = self.get_instance()
+        assert batch.mode == self.enum.PURCHASE_BATCH_MODE_ORDERING
+        assert not (batch.executed or batch.complete)
+
+        uuid = data.get('row_uuid')
+        row = self.Session.query(self.model_row_class).get(uuid) if uuid else None
+        if not row:
+            return {'error': "Row not found"}
+        if row.batch is not batch or row.removed:
+            return {'error': "Row is not active for batch"}
+
+        self.handler.update_row_quantity(row, **data)
+        return {'ok': True}
+
     def worksheet(self):
         """
         View for editing batch row data as an order form worksheet.
@@ -385,60 +450,6 @@ class OrderingBatchView(PurchasingBatchView):
             'batch_po_total_display': '${:0,.2f}'.format(batch.po_total_calculated or batch.po_total or 0),
         }
 
-    def render_mobile_listitem(self, batch, i):
-        return "({}) {} on {} for ${:0,.2f}".format(batch.id_str, batch.vendor,
-                                                    batch.date_ordered, batch.po_total or 0)
-
-    def mobile_create(self):
-        """
-        Mobile view for creating a new ordering batch
-        """
-        mode = self.batch_mode
-        data = {'mode': mode}
-
-        vendor = None
-        if self.request.method == 'POST' and self.request.POST.get('vendor'):
-            vendor = self.Session.query(model.Vendor).get(self.request.POST['vendor'])
-            if vendor:
-
-                # fetch first to avoid flush below
-                store = self.rattail_config.get_store(self.Session())
-
-                batch = self.model_class()
-                batch.mode = mode
-                batch.vendor = vendor
-                batch.store = store
-                batch.buyer = self.request.user.employee
-                batch.created_by = self.request.user
-                batch.po_total = 0
-                kwargs = self.get_batch_kwargs(batch, mobile=True)
-                batch = self.handler.make_batch(self.Session(), **kwargs)
-                if self.handler.should_populate(batch):
-                    self.handler.populate(batch)
-                return self.redirect(self.request.route_url('mobile.ordering.view', uuid=batch.uuid))
-
-        data['index_title'] = self.get_index_title()
-        data['index_url'] = self.get_index_url(mobile=True)
-        data['mode_title'] = self.enum.PURCHASE_BATCH_MODE[mode].capitalize()
-
-        data['vendor_use_autocomplete'] = self.rattail_config.getbool(
-            'rattail', 'vendor.use_autocomplete', default=True)
-        if not data['vendor_use_autocomplete']:
-            vendors = self.Session.query(model.Vendor)\
-                                  .order_by(model.Vendor.name)
-            options = [(tags.Option(vendor.name, vendor.uuid))
-                       for vendor in vendors]
-            options.insert(0, tags.Option("(please choose)", ''))
-            data['vendor_options'] = options
-
-        return self.render_to_response('create', data, mobile=True)
-
-    def configure_mobile_row_form(self, f):
-        super(OrderingBatchView, self).configure_mobile_row_form(f)
-        if self.editing:
-            # TODO: probably should take `allow_cases` into account here...
-            f.focus_spec = '[name="units_ordered"]'
-
     def download_excel(self):
         """
         Download ordering batch as Excel spreadsheet.
@@ -468,23 +479,10 @@ class OrderingBatchView(PurchasingBatchView):
 
         return self.file_response(path)
 
-    @classmethod
-    def _ordering_defaults(cls, config):
-        route_prefix = cls.get_route_prefix()
-        url_prefix = cls.get_url_prefix()
-        permission_prefix = cls.get_permission_prefix()
-        model_title = cls.get_model_title()
-        model_title_plural = cls.get_model_title_plural()
-
-        # fix permission group label
-        config.add_tailbone_permission_group(permission_prefix, model_title_plural)
-
-        # download as Excel
-        config.add_route('{}.download_excel'.format(route_prefix), '{}/{{uuid}}/excel'.format(url_prefix))
-        config.add_view(cls, attr='download_excel', route_name='{}.download_excel'.format(route_prefix),
-                        permission='{}.download_excel'.format(permission_prefix))
-        config.add_tailbone_permission(permission_prefix, '{}.download_excel'.format(permission_prefix),
-                                       "Download {} as Excel".format(model_title))
+    def get_execute_success_url(self, batch, result, **kwargs):
+        if isinstance(result, model.Purchase):
+            return self.request.route_url('purchases.view', uuid=result.uuid)
+        return super(OrderingBatchView, self).get_execute_success_url(batch, result, **kwargs)
 
     @classmethod
     def defaults(cls, config):
@@ -493,6 +491,37 @@ class OrderingBatchView(PurchasingBatchView):
         cls._batch_defaults(config)
         cls._defaults(config)
 
+    @classmethod
+    def _ordering_defaults(cls, config):
+        route_prefix = cls.get_route_prefix()
+        instance_url_prefix = cls.get_instance_url_prefix()
+        permission_prefix = cls.get_permission_prefix()
+        model_title = cls.get_model_title()
+        model_title_plural = cls.get_model_title_plural()
+
+        # fix permission group label
+        config.add_tailbone_permission_group(permission_prefix, model_title_plural,
+                                             overwrite=False)
+
+        # scanning entry
+        config.add_route('{}.scanning_entry'.format(route_prefix), '{}/scanning-entry'.format(instance_url_prefix))
+        config.add_view(cls, attr='scanning_entry', route_name='{}.scanning_entry'.format(route_prefix),
+                        permission='{}.edit_row'.format(permission_prefix),
+                        renderer='json')
+
+        # scanning update
+        config.add_route('{}.scanning_update'.format(route_prefix), '{}/scanning-update'.format(instance_url_prefix))
+        config.add_view(cls, attr='scanning_update', route_name='{}.scanning_update'.format(route_prefix),
+                        permission='{}.edit_row'.format(permission_prefix),
+                        renderer='json')
+
+        # download as Excel
+        config.add_route('{}.download_excel'.format(route_prefix), '{}/excel'.format(instance_url_prefix))
+        config.add_view(cls, attr='download_excel', route_name='{}.download_excel'.format(route_prefix),
+                        permission='{}.download_excel'.format(permission_prefix))
+        config.add_tailbone_permission(permission_prefix, '{}.download_excel'.format(permission_prefix),
+                                       "Download {} as Excel".format(model_title))
+
 
 def includeme(config):
     OrderingBatchView.defaults(config)
