@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -31,7 +31,7 @@ from rattail.db import model
 from tailbone.views import MasterView
 
 
-class ReportCodesView(MasterView):
+class ReportCodeView(MasterView):
     """
     Master view for the ReportCode class.
     """
@@ -51,13 +51,16 @@ class ReportCodesView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(ReportCodesView, self).configure_grid(g)
+        super(ReportCodeView, self).configure_grid(g)
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
         g.set_sort_defaults('code')
         g.set_link('code')
         g.set_link('name')
 
+# TODO: deprecate / remove this
+ReportCodesView = ReportCodeView
+
 
 def includeme(config):
-    ReportCodesView.defaults(config)
+    ReportCodeView.defaults(config)
