@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -46,7 +46,7 @@ from tailbone.db import Session
 from tailbone.views.principal import PrincipalMasterView, PermissionsRenderer
 
 
-class RolesView(PrincipalMasterView):
+class RoleView(PrincipalMasterView):
     """
     Master view for the Role model.
     """
@@ -67,7 +67,7 @@ class RolesView(PrincipalMasterView):
     ]
 
     def configure_grid(self, g):
-        super(RolesView, self).configure_grid(g)
+        super(RoleView, self).configure_grid(g)
 
         # name
         g.filters['name'].default_active = True
@@ -139,7 +139,7 @@ class RolesView(PrincipalMasterView):
             raise colander.Invalid(node, "Name must be unique")
 
     def configure_form(self, f):
-        super(RolesView, self).configure_form(f)
+        super(RoleView, self).configure_form(f)
         role = f.model_instance
         use_buefy = self.get_use_buefy()
 
@@ -226,7 +226,7 @@ class RolesView(PrincipalMasterView):
         """
         if data is None:
             data = form.validated
-        role = super(RolesView, self).objectify(form, data)
+        role = super(RoleView, self).objectify(form, data)
         self.update_permissions(role, data['permissions'])
         return role
 
@@ -373,6 +373,9 @@ class RolesView(PrincipalMasterView):
         config.add_view(cls, attr='download_permissions_matrix', route_name='{}.download_permissions_matrix'.format(route_prefix),
                         permission='{}.download_permissions_matrix'.format(permission_prefix))
 
+# TODO: deprecate / remove this
+RolesView = RoleView
+
 
 class PermissionsWidget(dfwidget.Widget):
     template = 'permissions'
@@ -396,4 +399,4 @@ class PermissionsWidget(dfwidget.Widget):
 
 
 def includeme(config):
-    RolesView.defaults(config)
+    RoleView.defaults(config)
