@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -43,7 +43,7 @@ from tailbone.db import Session
 from tailbone.views import MasterView, View
 
 
-class SettingsView(MasterView):
+class SettingView(MasterView):
     """
     Master view for the settings model.
     """
@@ -59,14 +59,14 @@ class SettingsView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(SettingsView, self).configure_grid(g)
+        super(SettingView, self).configure_grid(g)
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
         g.set_sort_defaults('name')
         g.set_link('name')
 
     def configure_form(self, f):
-        super(SettingsView, self).configure_form(f)
+        super(SettingView, self).configure_form(f)
         if self.creating:
             f.set_validator('name', self.unique_name)
 
@@ -85,6 +85,9 @@ class SettingsView(MasterView):
             return not bool(self.feedback.match(setting.name))
         return True
 
+# TODO: deprecate / remove this
+SettingsView = SettingView
+
 
 class AppSettingsForm(forms.Form):
 
@@ -267,4 +270,4 @@ class AppSettingsView(View):
 
 def includeme(config):
     AppSettingsView.defaults(config)
-    SettingsView.defaults(config)
+    SettingView.defaults(config)
