@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -48,7 +48,7 @@ def render_shift_length(shift, field):
     return HTML.tag('span', title="{} hrs".format(hours_as_decimal(length)), c=[pretty_hours(length)])
 
 
-class ScheduledShiftsView(MasterView):
+class ScheduledShiftView(MasterView):
     """
     Master view for employee scheduled shifts.
     """
@@ -83,12 +83,15 @@ class ScheduledShiftsView(MasterView):
         g.set_label('employee', "Employee Name")
 
     def configure_form(self, f):
-        super(ScheduledShiftsView, self).configure_form(f)
+        super(ScheduledShiftView, self).configure_form(f)
 
         f.set_renderer('length', render_shift_length)
 
+# TODO: deprecate / remove this
+ScheduledShiftsView = ScheduledShiftView
 
-class WorkedShiftsView(MasterView):
+
+class WorkedShiftView(MasterView):
     """
     Master view for employee worked shifts.
     """
@@ -114,7 +117,7 @@ class WorkedShiftsView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(WorkedShiftsView, self).configure_grid(g)
+        super(WorkedShiftView, self).configure_grid(g)
 
         g.joiners['employee'] = lambda q: q.join(model.Employee).join(model.Person)
         g.filters['employee'] = g.make_filter('employee', model.Person.display_name)
@@ -146,7 +149,7 @@ class WorkedShiftsView(MasterView):
         return "WorkedShift: {}, {}".format(shift.employee, date)
 
     def configure_form(self, f):
-        super(WorkedShiftsView, self).configure_form(f)
+        super(WorkedShiftView, self).configure_form(f)
 
         f.set_readonly('employee')
         f.set_renderer('employee', self.render_employee)
@@ -164,7 +167,7 @@ class WorkedShiftsView(MasterView):
         return tags.link_to(text, url)
 
     def get_xlsx_fields(self):
-        fields = super(WorkedShiftsView, self).get_xlsx_fields()
+        fields = super(WorkedShiftView, self).get_xlsx_fields()
 
         # add employee name
         i = fields.index('employee_uuid')
@@ -176,7 +179,7 @@ class WorkedShiftsView(MasterView):
         return fields
 
     def get_xlsx_row(self, shift, fields):
-        row = super(WorkedShiftsView, self).get_xlsx_row(shift, fields)
+        row = super(WorkedShiftView, self).get_xlsx_row(shift, fields)
 
         # localize start and end times (Excel requires time with no zone)
         if shift.punch_in:
@@ -200,7 +203,10 @@ class WorkedShiftsView(MasterView):
 
         return row
 
+# TODO: deprecate / remove this
+WorkedShiftsView = WorkedShiftView
+
 
 def includeme(config):
-    ScheduledShiftsView.defaults(config)
-    WorkedShiftsView.defaults(config)
+    ScheduledShiftView.defaults(config)
+    WorkedShiftView.defaults(config)
