@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,7 +32,7 @@ from tailbone.db import Session
 from tailbone.views import MasterView
 
 
-class SubdepartmentsView(MasterView):
+class SubdepartmentView(MasterView):
     """
     Master view for the Subdepartment class.
     """
@@ -58,7 +58,7 @@ class SubdepartmentsView(MasterView):
     ]
 
     def configure_grid(self, g):
-        super(SubdepartmentsView, self).configure_grid(g)
+        super(SubdepartmentView, self).configure_grid(g)
 
         # name
         g.filters['name'].default_active = True
@@ -74,7 +74,7 @@ class SubdepartmentsView(MasterView):
         g.set_link('name')
 
     def configure_form(self, f):
-        super(SubdepartmentsView, self).configure_form(f)
+        super(SubdepartmentView, self).configure_form(f)
         f.remove_field('products')
 
         # TODO: figure out this dang department situation..
@@ -98,6 +98,9 @@ class SubdepartmentsView(MasterView):
 
         Session.delete(removing)
 
+# TODO: deprecate / remove this
+SubdepartmentsView = SubdepartmentView
+
 
 def includeme(config):
-    SubdepartmentsView.defaults(config)
+    SubdepartmentView.defaults(config)
