@@ -326,6 +326,18 @@ class UpgradeView(MasterView):
                 'commit_url': 'https://kallithea.rattailproject.org/rattail-restricted/tailbone-onager/changelog/{new_version}/?size=10',
                 'release_url': 'https://kallithea.rattailproject.org/rattail-restricted/tailbone-onager/files/{new_version}/CHANGELOG.md',
             },
+            'rattail_woocommerce': {
+                'commit_url': 'https://kallithea.rattailproject.org/rattail-project/rattail-woocommerce/changelog/{new_version}/?size=10',
+                'release_url': 'https://kallithea.rattailproject.org/rattail-project/rattail-woocommerce/files/{new_version}/CHANGES.rst',
+            },
+            'tailbone_woocommerce': {
+                'commit_url': 'https://kallithea.rattailproject.org/rattail-project/tailbone-woocommerce/changelog/{new_version}/?size=10',
+                'release_url': 'https://kallithea.rattailproject.org/rattail-project/tailbone-woocommerce/files/{new_version}/CHANGES.rst',
+            },
+            'tailbone_theo': {
+                'commit_url': 'https://kallithea.rattailproject.org/rattail-project/theo/changelog/{new_version}/?size=10',
+                'release_url': 'https://kallithea.rattailproject.org/rattail-project/theo/files/{new_version}/CHANGES.rst',
+            },
         }
         return projects
 
