@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -44,7 +44,7 @@ from tailbone.views import MasterView
 from tailbone.views.principal import PrincipalMasterView, PermissionsRenderer
 
 
-class UsersView(PrincipalMasterView):
+class UserView(PrincipalMasterView):
     """
     Master view for the User model.
     """
@@ -96,7 +96,7 @@ class UsersView(PrincipalMasterView):
     ]
 
     def query(self, session):
-        query = super(UsersView, self).query(session)
+        query = super(UserView, self).query(session)
 
         # bring in the related Person(s)
         query = query.outerjoin(model.Person)\
@@ -105,7 +105,7 @@ class UsersView(PrincipalMasterView):
         return query
 
     def configure_grid(self, g):
-        super(UsersView, self).configure_grid(g)
+        super(UserView, self).configure_grid(g)
 
         del g.filters['salt']
         g.filters['username'].default_active = True
@@ -163,7 +163,7 @@ class UsersView(PrincipalMasterView):
             raise colander.Invalid(node, "Username must be unique")
 
     def configure_form(self, f):
-        super(UsersView, self).configure_form(f)
+        super(UserView, self).configure_form(f)
         user = f.model_instance
 
         # username
@@ -264,26 +264,28 @@ class UsersView(PrincipalMasterView):
         # create/update user as per normal
         if data is None:
             data = form.validated
-        user = super(UsersView, self).objectify(form, data)
+        user = super(UserView, self).objectify(form, data)
 
         # create/update person as needed
         names = {}
-        if 'first_name_' in form:
+        if 'first_name_' in form and data['first_name_']:
             names['first'] = data['first_name_']
-        if 'last_name_' in form:
+        if 'last_name_' in form and data['last_name_']:
             names['last'] = data['last_name_']
-        if 'display_name_' in form:
-            names['display'] = data['display_name_']
+        if 'display_name_' in form and data['display_name_']:
+            names['full'] = data['display_name_']
+        # we will not have a person reference yet, when creating new user.  if
+        # that is the case, go ahead and load it, if specified.
+        if self.creating and user.person_uuid:
+            self.Session.add(user)
+            self.Session.flush()
         # note, do *not* create new person unless name(s) provided
         if not user.person and any([n for n in names.values()]):
             user.person = model.Person()
         if user.person:
-            if 'first' in names:
-                user.person.first_name = names['first']
-            if 'last' in names:
-                user.person.last_name = names['last']
-            if 'display' in names:
-                user.person.display_name = names['display']
+            app = self.get_rattail_app()
+            handler = app.get_people_handler()
+            handler.update_names(user.person, **names)
 
         # force "local only" flag unless global access granted
         if self.secure_global_objects:
@@ -354,7 +356,7 @@ class UsersView(PrincipalMasterView):
                            .filter(model.UserEvent.user == user)
 
     def configure_row_grid(self, g):
-        super(UsersView, self).configure_row_grid(g)
+        super(UserView, self).configure_row_grid(g)
         g.width = 'half'
         g.filterable = False
         g.set_sort_defaults('occurred', 'desc')
@@ -395,7 +397,7 @@ class UsersView(PrincipalMasterView):
         }
 
     def get_merge_resulting_data(self, remove, keep):
-        result = super(UsersView, self).get_merge_resulting_data(remove, keep)
+        result = super(UserView, self).get_merge_resulting_data(remove, keep)
         result['role_count'] = len(set(remove['_roles'] + keep['_roles']))
         return result
 
@@ -426,8 +428,11 @@ class UsersView(PrincipalMasterView):
         config.add_tailbone_permission(permission_prefix, '{}.edit_roles'.format(permission_prefix),
                                        "Edit the Roles to which a {} belongs".format(model_title))
 
+# TODO: deprecate / remove this
+UsersView = UserView
 
-class UserEventsView(MasterView):
+
+class UserEventView(MasterView):
     """
     Master view for all user events
     """
@@ -446,11 +451,11 @@ class UserEventsView(MasterView):
     ]
 
     def get_data(self, session=None):
-        query = super(UserEventsView, self).get_data(session=session)
+        query = super(UserEventView, self).get_data(session=session)
         return query.join(model.User)
 
     def configure_grid(self, g):
-        super(UserEventsView, self).configure_grid(g)
+        super(UserEventView, self).configure_grid(g)
         g.set_joiner('person', lambda q: q.outerjoin(model.Person))
         g.set_sorter('user', model.User.username)
         g.set_sorter('person', model.Person.display_name)
@@ -471,7 +476,10 @@ class UserEventsView(MasterView):
         if event.user.person:
             return event.user.person.display_name
 
+# TODO: deprecate / remove this
+UserEventsView = UserEventView
+
 
 def includeme(config):
-    UsersView.defaults(config)
-    UserEventsView.defaults(config)
+    UserView.defaults(config)
+    UserEventView.defaults(config)
