@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,7 +26,9 @@ Views pertaining to vendors
 
 from __future__ import unicode_literals, absolute_import
 
-from .core import VendorsView, VendorsAutocomplete
+from .core import VendorView, VendorsAutocomplete
+# TODO: deprecate / remove this
+from .core import VendorsView
 
 
 def includeme(config):
